*********************************************************************************************
*********************************************************************************************
* v11 done by BB, following up v10 by Kenzo Asahi in 2012 
* v13 is BCS 2012 added final version for Addiction submission
* v14 is for Addiction revised submission
*********************************************************************************************
*********************************************************************************************

clear 
macro drop _all						// Must do this BEFORE setting the dir globals below!
pause on
set more off, permanently	
* To install: SSC INSTALL (gllamm | estout | estwrite) net install dm79, from(http://www.stata.com/stb/stb56) =SVMAT2 | net install spost9_ado, from(http://www.indiana.edu/~jslsoc/stata) =MISSCHK | dm88_1.pkg (RENVARS) | estwrite, from(http://fmwww.bc.edu/RePEc/bocode/e)

// Directories
capture cd "C:\Users\bpb\Dropbox\Alcohol work\IARP\BCS code"
	if _rc==0	{
	global dir		"C:\Users\bpb\Desktop\Datasets misc\BCS\BCS working"
	global dodir	"C:\Users\bpb\Dropbox\Alcohol work\IARP\BCS code"
/**/		}
capture log close
	local cmth = month(date("`c(current_date)'", "DMY"))
	local cyr  = year(date("`c(current_date)'", "DMY"))
	log using "$dir\logs\BCSlog`cyr'-`cmth'.txt", text append
global filename "BCS-v3-1"									// BB update 27/2/2015 - for Addiction revisions
cd "$dir"

// Loading things up
use "${filename}.dta", replace
do "${dodir}\4_alc86_globals_v1.do"					// Also used above, hence separated out
do "${dodir}\6_analysis_globals_v3.do"	
estread using "${dir}\estimates_OLSandFE_${filename}", id(uniqueid)
dis _newline(10) in red "Open up 6_analysis_v5.do"
exit




//////////////////////////////////////////////////////
//////////////////////////////////////////////////////
// PUTTING DATAFILE TOGETHER
//////////////////////////////////////////////////////
//////////////////////////////////////////////////////

do "${dodir}\1_picking_vars_v15.do"			
	* use temp\bcs1986-2012, replace
do "${dodir}\2_data_cleaning_v9.do"			
	* use temp\bcs1986-2012_recoded_miss, replace 	// Also creates temp\bcs1984-2004_2_new_vars, temp\bcs2000_total_adults, temp\bcs2004_total_adults
do "${dodir}\3_dvs_v19.do"					
	* use temp\bcs1986-2012-incpcapita+alcohol, replace	// Also creates temp\bcs1984-2004_2_new_vars, temp\bcs1984-2004_3_new_vars
	save "${filename}", replace
do "${dodir}\4_highest_educ_v17.do"					
	* use temp/bcs1986-2012-incpc+alc+ed, replace
	save "${filename}", replace
*use "${filename}", replace
	
	
// Further data cleaning
*4_Further cleaning.do
	*global alctrim		"200"							// This has been moved into the analysis_globals, for ${maxalc}
	do "${dodir}\4_further_cleaning_v4.do"				// THIS WAS v1 in the text, but I didn't have this
	* use temp/postsecondclean, replace
	save "${filename}.dta", replace
*4_Factors.do
	do "${dodir}\4_alc86_globals_v1.do"					
	do "${dodir}\4_factors_v2.do"		
	* use temp\pre_reshape.dta, replace	
	save "${filename}.dta", replace
*5_reshaping.do
	capture drop *96									// Not using 1996 data - see note on alcohol consumption variable
	do "${dodir}\5_reshaping_v1.do"		
	save "${filename}.dta", replace
* Further data preparation in response to reviewers' requests
	// Request #1: to estimate models only on the sub-sample of people that switch drinking group - see also in 0_master.do
	capture drop FalcgrpOLD 
	gen FalcgrpOLD = F.alcgrpOLD								// This creates a variable for each person-wave observation of the alcohol consumption at the NEXT wave
		replace FalcgrpOLD = F2.alcgrpOLD if missing(FalcgrpOLD)	// The FE model also uses wave 1->3 transitions, so it's worth adding these
		label var FalcgrpOLD "Next wave alcgrpOLD (reviewer sensitivity analysis)"
	gen chalcOLD = (alcgrpOLD~=FalcgrpOLD) if ~missing(alcgrpOLD, FalcgrpOLD)
		label var chalcOLD "Any change in alcgrpOLD between this and +1 wave (or +2 wave if +1 wave missing)"
	bysort bcsnumid: egen anychange = max(chalcOLD)
		label var anychange "Any change in alcgrpOLD between waves (w1->2, w2->3 or w1->3)"
	/* 	A quicker way of doing this would be:
			bysort bcsnumid: egen test = sd(alcgrpOLD)		// I've checked, and this is missing for anyone with <2 observations
		However, I've checked and this produces exactly the same result
	END NOTE */
		
	// Request #2: to control for lagged dependent variable (despite bias, this may bound the true value)
	capture drop Llifesat
	gen Llifesat = L.lifesat
		label var Llifesat "Lagged lifesat (reviewer sensitivity analysis)"
	save "${filename}.dta", replace


	
	
//////////////////////////////////////////////////////
//////////////////////////////////////////////////////
// ANALYSES
//////////////////////////////////////////////////////
//////////////////////////////////////////////////////

use "${filename}.dta", replace

* Full analyses
do "${dodir}\4_alc86_globals_v1.do"					// Also used above, hence separated out
do "${dodir}\6_analysis_globals_v3.do"	
do "${dodir}\6_analysis_v5.do"	
*do "${dodir}\6_analysis_IV_from_v4.do"				// Taken out at the request of the Addiction reviewers




*********************************************
* Checks in the paper
*********************************************

// Checking consistency of alc cons between waves
bysort alcfreq: tab alctotunNEW if wavenum==3 & alcfreq>=4

// Checking wave-to-wave transitions (requested by Reviewer 1, but also checked before this)
estimates restore lin21							// This is the main OLS model in Table 1 - FE models use the same sample by design
gen FalcgrpOLD = F.alcgrpOLD					// This creates a variable for each person-wave observation of the alcohol consumption at the NEXT wave
replace FalcgrpOLD = F2.alcgrpOLD if missing(FalcgrpOLD)	// The FE model also uses wave 1->3 transitions, so it's worth adding these
tab alcgrpOLD FalcgrpOLD if e(sample), row nof	// I then exported this to Excel for using in the paper's appendices
tab alcgrpOLD FalcgrpOLD if e(sample)			// I then exported this to Excel for using in the paper's appendices
* Further checking if there is a big difference between the wave 1->2 transition and the wave 2->3 transition - but there isn't
tab alcgrpOLD FalcgrpOLD if e(sample) & wavenum==1, row nof
tab alcgrpOLD FalcgrpOLD if e(sample) & wavenum==2, row nof

// Checking never-drinkers
estimates restore lin21							// This is the main OLS model in Table 1 - FE models use the same sample by design
tab alcgrpOLD nevdrk if e(sample), row nof




*********************************************
* Descriptives for the paper
*********************************************

estimates restore lin21
	capture drop descinsample
	gen descinsample = 1 if e(sample)
capture estimates drop app_*
local catvars	"lifesat nevdrk alcgrpOLD alcgrpNEW alcfreq cageyr male hinvq04 cohab anykids0_5 anykids6_17"
local catvars	"`catvars' activ wrktrav wrkhoursG lsi housing relweek currsmk pregnant poorhlth support"
local contvars	"lifesat alctotunOLD alctotunNEW loginc cigsday delinqscore86"
* Simple sociodemographic comparison that includes ALL years, for appendix
foreach var in `catvars' {
	eststo appcat_`var' : proportion `var' if descinsample==1 ${ifall} , over(wavenum, nolabel)
	/**/																		}
foreach var in `contvars' 	{
	eststo appcont_`var': mean       `var' if descinsample==1 ${ifall} , over(wavenum, nolabel)
	/**/					}
esttab appcat_* using "${dodir}\0.appendix_categorical.csv", varwidth(25) not nostar nonum nodepvars csv coeflabels() replace
esttab appcont_* using "${dodir}\0.appendix_continuous.csv", varwidth(25) not nostar nonum nodepvars csv coeflabels() replace		
	

