**********************************************
* CHECKING THE FULL LIST FOR MISSINGNESS
**********************************************	

global alcfactors "${alc_expectations} ${alc_perceived_harm} ${alc_attitudes_other} ${alc_whystop}"
	des $alcfactors
	sum $alcfactors, sep(0)
*	codebook $alcfactors
foreach set in alc_expectations alc_perceived_harm alc_attitudes_other alc_whystop	{
	egen miss`set' = rowmiss(${`set'})
	/**/																			}
egen missHAD = rowmiss($alc_expectations_HAD $alc_perceived_harm_HAD $alc_attitudes_other_HAD)
egen missFOW = rowmiss($alc_expectations_FOW $alc_perceived_harm_FOW $alc_whystop_FOW)
gen missall = missHAD + missFOW
misstable patterns $alcfactors
drop miss*



	
	
**********************************************
* NORMAL FACTOR ANALYSIS
**********************************************

/* Deciding how many factors using a scree plot
	factor ${alcfactors}, factors(5)
	screeplot
*/

* Choosing 4 factors
factor ${alcfactors}, factors(4)
	rotate, promax horst blanks(.2)
	estat common
	predict alcfac*
	rename alcfac? alcfac?_86 // Added 27/7/13

	
	
	
**********************************************
* FACTOR ANALYSIS FOR BINARY/ORDINAL VARIABLES
**********************************************
pause Uses a saved version of the slow (30min) POLYCHORIC analysis - check the n in polychoric.txt
/*
	time
polychoric ${alcfactors}  	// Using technique described at http://www.ats.ucla.edu/stat/stata/faq/efa_categorical.htm
	time					// Polychoric takes 30mins on laptop as of 29/7/2013
	local polynum 	= r(sum_w)
	matrix r 	= r(R)
	mat2txt, matrix(r) saving("$dodir\polychor") note("Outputted `c(current_date)'; number of cases = `polynum'") replace
*/ 
* 	AFTER ORIGINAL COMMAND HAS BEEN RUN, TO RE-ROTATE ETC
	preserve
		clear
		insheet using "${dodir}\polychor.txt"
		drop if _n==47
		drop v1 v48
		unab vars: _all
		mkmat `vars', matrix(r)
	restore
	local rows: colnames r
	matrix rownames r = `rows'
	factormat r, n(3734) factors(4) forcepsd			// Sometimes not positive definite so needs forcepsd option - for explanation of pos def see http://www.stata.com/statalist/archive/2006-09/msg00690.html
		/* For checking number of factors
		screeplot
		graph save Graph "C:\Users\bpb\Dropbox\Alcohol work\IARP\BCS code\Factor screeplot (polychoric).gph", replace
		*/
	rotate, promax horst blanks(.2)
	estat common
predict alcpolyfac*
	rename alcpolyfac? alcpolyfac?_86 // Added 27/7/13
	label var alcpolyfac1_86	"Alc factor: alcohol-related delinquency"
	label var alcpolyfac2_86	"Alc factor: social drinking not excess"
	label var alcpolyfac3_86	"Alc factor: general positive (not about personal)"
	label var alcpolyfac4_86	"Alc factor: unpleasant effects"


	
	
	
	
**********************************************
* FACTORS FOR CONTROLS
**********************************************

//////////////////////////////////////
// Parental expectations
global parexpect "ptexwkndB86 ptextimeB86 ptexwhrB86 ptexwhoB86 ptexfrlkB86 ptexdoB86"
	capture label define c5t10 0 "0_false", modify
	foreach var in $parexpect	{
		recode `var' (2=0)
		label values `var' c5t10
		/**/					}
	codebook ${parexpect}
	sum ${parexpect}
	misstable patterns ${parexpect}
time
polychoric ${parexpect}  	// 
time						// Polychoric takes 40secs on laptop as of 29/7/2013
	local polynum 	= r(sum_w)
	matrix r 	= r(R)
factormat r, n(`polynum') factors(1) forcepsd			
	*screeplot
	rotate, promax horst blanks(.2)
	estat common
predict parexpect86
	label var parexpect86		"Parental expectations/obedience single factor"


	
//////////////////////////////////////
// Smoking attitudes
rename smk*N86 smk*86
global smokfac "smkbadyrs86 smkkiddpun86 smklowwgt86 smkhrmnon86 smkadvban86 smkregcan86 smkenjoy86 smkbankid86 smkbadlot86 smkwthfrd86 smkprghrm86 smklivlng86 smkhrdget86 smkothfun86 smkdirhab86 smknotdng86 smkhlpnrv86"
	sum ${smokfac}
	misstable patterns ${smokfac}
	misschk ${smokfac}
time
polychoric ${smokfac}  	// 
time						// Polychoric takes 5mins on laptop as of 29/7/2013
	local polynum 	= r(sum_w)
	matrix r 	= r(R)
	mat2txt, matrix(r) saving("$dodir\polychor_smok") replace
	/*
	preserve
		clear
		insheet using "${dodir}\polychor_smok.txt"
		drop v1 v19
		unab vars: _all
		mkmat `vars', matrix(r)
	restore
	local rows: colnames r
	matrix rownames r = `rows'
	*/
*factormat r, n(`polynum') factors(3) forcepsd			
factormat r, n(4688) factors(3) forcepsd			
	* screeplot
	rotate, promax horst blanks(.2)
	estat common
predict smokpolyfac1_86 smokpolyfac2_86
	label var smokpolyfac1_86 	"Smoking attitudes: smoking is bad"
	label var smokpolyfac2_86 	"Smoking attitudes: smoking is good socially/pleasure"


	
//////////////////////////////////////
// Drug attitudes
global drugfac "drgstsfthar86 drgstcrimi86 drgst1addic86 drgstherdi86 drgstunsta86 drgsthelp86"
	sum ${drugfac}
	misstable patterns ${drugfac}
	misschk ${drugfac}
time
polychoric ${drugfac}  	// 
time						// Polychoric takes 40secs on laptop as of 29/7/2013
	local polynum 	= r(sum_w)
	matrix r 	= r(R)
factormat r, n(`polynum') factors(1) forcepsd			
	*screeplot
	rotate, promax horst blanks(.2)
	estat common
predict drugpolyfac86
	label var drugpolyfac86 	"Drug attitudes: NOTE high missingness as from student s/c"
	
	

	
	
save temp\pre_reshape.dta, replace

