//////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////
// CLEANING
//////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////


/////////////////////////////
// MAKING SEX CLEAR
egen anymale 	= anymatch(sex86 sex96 sex00 sex04), values(1)
egen anyfemale 	= anymatch(sex86 sex96 sex00 sex04), values(2)
gen male = anymale
	list bcsid sex* if anymale==1 & anyfemale==1	// No changes need to be made - happy to treat B21994X as male (as male in 2000) and B19923K also as male (as didn't change till 2004)
drop anymale anyfemale sex?? 

	


**************************************************************
**************************************************************
**************************************************************
** Alcohol vars 1986
**************************************************************
**************************************************************
**************************************************************


/////////////////////////////////////////////////
// RARE/NEVER DRINKERS
* If people say they can't answer because they don't drink much and then miss out other q's, this answer is assumed more broadly
local afterdrinkvars	"drafbrkthn86 drafdrvcar86 draffight86 drafnothom86 drafupsfrd86 drafupspar86 drafupsprt86"
capture egen raredrinkA86 = anymatch(`afterdrinkvars'), values(4)
foreach var in `afterdrinkvars' {
	replace `var' = 4 if raredrinkA86==1 & missing(`var')
	/**/						}
label var raredrinkA86	"Drink rarely/never so can't answer some of perceived harm q's"

* Creating a dummy var for equivalent responses in multicoded vars on pleasant/unpleasant effects
gen raredrinkB86 = (drpenevdrk86==1) if ~missing(drpenevdrk86)
	replace raredrinkB86 = 1 if unpalnvd86==1 | stpalnev86==1
	label var raredrinkB86 "Drink rarely/never so can't answer pleasant/unpleasant effect qs"
gen raredrink86 = (raredrinkB86==1 | raredrinkA86==1) if ~missing(raredrinkB86) & ~missing(raredrinkA86)
	label var raredrink86 "Drink rarely/never so can't answer pleasant/unpleasant/perceived harm qs"

	

/////////////////////////////
// RESPONSE CODES IN RIGHT DIRECTION
local cleanlist "nopbnofn86 dkattrct86 dkfight86 dkntrlmn86 dkadenjy86 dknowrng86 dkfriend86 dkstpnsh86 dkbdhlth86"
	local cleanlist "`cleanlist' dklkself86 dktpwrld86 dkhlpshy86 dkwrryad86 dkntdang86 dkenjoy86 dkprghrm86 dkflease86"
capture label define c5c_reversed 1 "1_disagree" 2 "2_agree partly" 3 "3_agree fully"
foreach var in `cleanlist' 	{
	rename `var' `var'O 
		local thislabel: var label `var'O
	recode `var'O (1=3) (3=1), gen(`var')
		label var `var' "`thislabel' REVERSED"
		label values `var' c5c_reversed
	/**/					}
unab draflist: draf*86
capture label define hd17_edited 1 "1_no never or rarely/never drink" 2 "2_yes once" 3 "3_yes more than once"
foreach var in `draflist' 	{
	rename `var' `var'O 
		local thislabel: var label `var'O
	recode `var'O (1 4=1) (2=2) (3=3), gen(`var')
		label var `var' "`thislabel' MERGED RESPONSES"
		label values `var' hd17_edited
	/**/					}
drop drafpolice86 		// This is done just above incorrectly
	recode drafpolice86 (4 3=1 "1_never or not drunk to excess") (1=2 "2_yes once") (2=3 "3_yes more than once"), gen(drafpolice86)
unab zeroone: drpe*86 unpal*86 stpal*86
capture label define mentioned 1 "1_mentioned" 0 "0_not mentioned"
foreach var in `zeroone' 	{
	rename `var' `var'O 
		local thislabel: var label `var'O
	recode `var'O (1=1) (2=0), gen(`var')
		label var `var' "`thislabel' RECODED"
		label values `var' mentioned
	/**/					}

	
	
	
	
	
/////////////////////////////
/* SPENDING ON ALC/TOB, SCALED PP
foreach type in alc tobc	{
	capture drop exp`type'pp86 
	gen exp`type'pp86 = exp`type'86/exp`type'n86 if exp`type'86>0 & exp`type'n86>0 & !missing(exp`type'n86)
	replace exp`type'pp86 = exp`type'86 if exp`type'n86==0 | exp`type'86==0
	label var exp`type'pp86 "amount spent on `type' per person per year (dv)"
	/**/					}
*/

	
/////////////////////////////
// PARENTAL/PEER DRINKING - GROUPED CATS
recode dkalfa86 (1/2=1) (3=2) (4=3) (else=.), gen(alcdad86)
	label var alcdad86 "Father's drinking frequency (GROUPED)"
	capture label define alcpar86 1 "1_never/occasionally" 2 "2_some days" 3 "3_most days"
	label values alcdad86 alcpar86
recode dkalmo86 (1/2=1) (3=2) (4=3) (else=.), gen(alcmum86)
	label var alcmum86 "Mother's drinking frequency (GROUPED)"
	label values alcmum86 alcpar86
egen alcpar86 = rowmax(alcdad86 alcmum86) if !missing(alcdad86, alcmum86)
	label var alcpar86 "Max parent's drinking frequency (GROUPED)"	
	label values alcpar86 alcpar86
/*
recode dkalbfrd86 (1/2=1) (3=2) (4=3) (else=.), gen(alcbest86)
	label var alcbest86 "Best friend's drinking frequency (GROUPED)"
	label values alcbest86 alcpar86
recode dkalnext86 (1/2=1) (3=2) (4=3) (else=.), gen(alc2best86)
	label var alc2best86 "Next best friend's drinking frequency (GROUPED)"
	label values alc2best86 alcpar86
egen alcfriend86 = rowmax(alc2best86 alcbest86) if !missing(alc2best86, alcbest86)
	label var alcfriend86 "Max friend's drinking frequency (GROUPED)"	
	label values alcfriend86 alcpar86
*/
gen dkview86 = 1 if dkviewmo86==2 & dkviewfa86==2	
	replace dkview86 = 2 if dkviewmo86==1 | dkviewfa86==1
	replace dkview86 = 3 if dkviewmo86==3 | dkviewfa86==3
	label define dkview86 1 "1_Both parents know and don't worry" 2 "2_1+ parent DK but no arguments" 3 "3_1+ parent argues", modify
	label values dkview86 dkview86
	label var dkview86 "Parents' attitude to teen's drinking (dv)"
egen pregdrink80 = rowmin(prgdrkearl80  prgdrklate80)
	label var pregdrink80 "Drinking during pregnancy (most frequent of early or late)"
	
	
	
	
	
**************************************************************
**************************************************************
**************************************************************
** Alcohol vars in adults
**************************************************************
**************************************************************
**************************************************************

	
////////////////////////////////
// CAGE - added since v1
unab cagevars: cage*
foreach var in `cagevars'	{
	capture clonevar `var'_O = `var'
	recode `var' (1=1) (2=0)
	replace `var' = 0 if drinks00==7		// q wasn't asked to lifelong abstainers
	/**/					}
foreach yr in 00 04		{
	replace cage2`yr' = 0 if cage1`yr'==0
	replace cage4`yr' = 0 if cage3`yr'==0
	replace cage6`yr' = 0 if cage5`yr'==0
	replace cage8`yr' = 0 if cage7`yr'==0
	egen cageyrct`yr' 		 = rowtotal(cage2`yr' cage4`yr' cage6`yr' cage8`yr')
		label var cageyrct`yr' "CAGE: count of probs in past year, 20`yr'"
		egen Mcageyr`yr' 	 =  rowmiss(cage2`yr' cage4`yr' cage6`yr' cage8`yr')
		replace cageyrct`yr' 	 = . if Mcageyr`yr'>0
	egen cagelifect`yr' 		 = rowtotal(cage1`yr' cage3`yr' cage5`yr' cage7`yr')
		label var cagelifect`yr' "CAGE: count of probs in lifetime, 20`yr'"
		egen Mcagelife`yr' 	 =  rowmiss(cage1`yr' cage3`yr' cage5`yr' cage7`yr')
		replace cagelifect`yr' = . if Mcagelife`yr'>0
	gen cagelife`yr' = (cagelifect`yr'>=2) if !missing(cagelifect`yr')
		label var cagelife`yr' "CAGE problems: 2+ lifetime probs"
	gen cageyr`yr' = (cageyrct`yr'>=2) if !missing(cageyrct`yr')
		label var cageyr`yr' "CAGE problems: 2+ probs in past 12mths"
	/**/				}
drop cage*_O
drop Mcage*
	
	
					/////////////////////////////
					// FORM OF ALCOHOL CONSUMPTION - but in practice, alcsq is generated after the reshaping, so this is redundant
					/*foreach yr in 00 04 12	{
						foreach version in OLD NEW		{
							gen alcsq`version'`yr' = alctotun`version'`yr'^2
								label var alcsq`version'`yr' "Alcohol consumption squared (from alctotun`version'`yr')"
							gen lnalc`version'`yr' = ln(alctotun`version'`yr'+0.00001)
								label var lnalc`version'`yr' "Ln alcohol consumption (from alctotun`version'`yr')"
							gen lnalcsq`version'`yr' = lnalc`version'`yr'^2
								label var lnalcsq`version'`yr' "Ln alcohol consumption squared (from alctotun`version'`yr')"
						/**/							}
					/**/							}
					foreach yr in 86 {
							capture gen alcsq`yr' = alctotun`yr'^2
								label var alcsq`yr' "Alcohol consumption squared (from alctotun`yr')"
							capture gen lnalc`yr' = ln(alctotun`yr'+0.00001)
								label var lnalc`yr' "Ln alcohol consumption (from alctotun`yr')"
							capture gen lnalcsq`yr' = lnalc`yr'^2
								label var lnalcsq`yr' "Ln alcohol consumption squared (from alctotun`yr')"
					/**/		}
					*/
				
					/* Generating the piecewise var that splits at 21 units - I've dropped this
						capture drop alclo?? alchi??
						foreach yr in 96 00 04	{
							gen alclo`yr' = alctotun`yr' - 21
								replace alclo`yr' = 0 if (alctotun`yr'>21 & !missing(alctotun`yr'))
							gen alchi`yr' = alctotun`yr' - 21
								replace alchi`yr' = 0 if (alctotun`yr'<=21)
							list alctotun`yr' alchi`yr' alclo`yr' in 1/10
						/**/					}
						*/

	
///////////////////////////////
//Drinking frequency & never drinking/, trying to make comparable between waves

foreach yr in 00 04	{
	gen nevdrk`yr' 	= (drinks`yr'==6 | drinks`yr'==7) if !missing(drinks`yr')
		label var nevdrk`yr' "Never drinks these days (dv from drinks`yr')"
	recode drinks`yr' (1=1)(2=2)(3/4=3)(5=4)(6/7=5) , gen(alcfreq`yr')
		label var alcfreq`yr' "Drinking freq, made roughly comparable 2000/04/12"
	* This isn't available in 2012 so I've removed this
	*gen nodrk`yr' 	= (drinks`yr'>=5 & drinks`yr'<=7) if !missing(drinks`yr')
	*	label var nodrk`yr' "Doesn't currently drink regularly (dv from drinks`yr')"
	/**/			}
gen nevdrk12 = (scq3212==1) if !missing(scq3212)
	label var nevdrk12 "Never drinks (dv from scq3212)"
recode scq3212 (5=1)(4=2)(3=3)(2=4)(1=5), gen(alcfreq12)
	label var alcfreq12 "Drinking freq, made roughly comparable 2000/04/12"
label define alcfreq 1 "1_most days/4+ days" 2 "2_2-3 times/wk" 3 "3_2-4 times/mth / 2/3 times/mth + weekly" ///
	4 "4_less often or spec occs / monthly or less" 5 "5_never nowadays", modify
label values alcfreq00 alcfreq
label values alcfreq04 alcfreq
label values alcfreq12 alcfreq
tab1 alcfreq* nevdrk*
drop scq3212

/////////////////////////////
// GROUPED ALCOHOL CONSUMPTION - added since v1
foreach yr in 00 04 12	{
	foreach version in OLD NEW	{
		recode alctotun`version'`yr' (0=0 "0_non-drinker") (0.001/1=1 "1_<1unit/wk") (1.001/10=2 "2_1-10 units") (10.001/21=3 "3_10-21 units") 		///
			(21.001/35=4 "4_21-35 units") (35.001/50=5 "5_35-50 units") (50/max=6 "6_50+ units") if male==1, gen(alcgrp_male`version'`yr')			// Categories are taken from HSE 2011 data docs:116
		recode alctotun`version'`yr' (0=0 "0_non-drinker") (0.001/1=1 "1_<1unit/wk") (1.001/7=2 "2_1-7 units") (7.001/14=3 "3_7-14 units") 			///
			(14.001/21=4 "4_14-21 units") (21.001/35=5 "5_21-35 units") (35/max=6 "6_35+ units") if male==0, gen(alcgrp_female`version'`yr')		// Categories are taken from HSE 2011 data docs:116
		gen 	alcgrp`version'`yr' =  alcgrp_male`version'`yr'   if male==1 & ~missing(alcgrp_male`version'`yr')
		replace alcgrp`version'`yr' =  alcgrp_female`version'`yr' if male==0 & ~missing(alcgrp_female`version'`yr')
			label define alcgrp 0 "0_non-drinker" 1 "1_<1 unit/wk" 2 "2_1-10/7 units" 3 "3_10-21/ 7-14 units" ///
				4 "4_21-35/ 14-21 units" 5 "5_35-50/ 21-35 units" 6 "6_50+/35+ units", modify
			label values alcgrp`version'`yr' alcgrp
	/**/						}
/**/						}
drop alcgrp_male* alcgrp_female*
	

	
**************************************************************
**************************************************************
**************************************************************
** Non-alcohol vars
**************************************************************
**************************************************************
**************************************************************

/////////////////////////////
// LIFESAT - CONSISTENT VARNAMES OVER 1996-2004
*lifesat96 already exists
ren lifesat100		lifesat00
ren lifet104		lifesat04
ren lifst1			lifesat12
drop lifesat200 lifet204

* Happiness question in 2000, within GHQ scale
mvdecode ghq1200, mv(8=.d \ 9=.r)
rename ghq1200		happy00


/////////////////////////////
// EMPLOYMENT STATUS
ren ecact04		econact04
mvdecode econact00, mv(98=.d \ 99=.r)
foreach yr in 00 04 12	{
	recode econact`yr' (1/4=1 "1_emp") (5/12=0 "0_not emp"), gen(emp`yr')
		label var emp`yr' "Employed in 20`yr', exc f/t educ & gov sch"
	recode econact`yr' (1/2=1 "1_employee") (3/4=2 "2_self-emp") (5 7=3 "3_unemp/gov sch") (6=4 "4_ed") ///
			(7/12=5 "5_oth inactive"), gen(activ`yr')
		label var activ`yr' "Economiac activity in 20`yr', six-group"
	/**/				}
drop econact*
	
	
/////////////////////////////
// LOG INCOME
foreach yr in 00 04	12 	{
	gen loginc`yr' = log((netpcinc`yr'+1)/1000)			// The +1 follows Massin & Kopp, and is to stop us dropping people wiht an income of zero
	label var loginc`yr' "Log equivalised hhld income (k+1) (dv)"
/**/					}


	
/////////////////////////////
// TRAVEL TO WORK TIME - added since v1, needed alongside income
recode travtowk00 (1/2 9=1 "1_<15mins")(3=2 "2_15-30mins")(4/5=3 "3_30-60mins")(6/8=4 "4_>1hr")(10=5 "5_no fixed wrkplace")(98=.d)(99=.r), gen(wrktrav00)
	label var wrktrav00 "Travel time to work, grouped"
	replace wrktrav00 = 1 if activ00>=3 & activ00<=5
recode travwk04   (1/2 9=1 "1_<15mins")(3=2 "2_15-30mins")(4/5=3 "3_30-60mins")(6/8=4 "4_>1hr")(10=5 "5_no fixed wrkplace")(98=.d) (99=.r), gen(wrktrav04)
	label var wrktrav04 "Travel time to work, grouped"
	replace wrktrav04 = 1 if activ04>=3 & activ04<=5
gen travmins12 = tvrthr12*60 + tvrtmn12
recode travmins12 (0/14=1 "1_<15mins")(15/29=2 "2_15-30mins")(30/59=3 "3_30-60mins")(60/max=4 "4_>1hr"), gen(wrktrav12)	
	replace wrktrav12 = .d if tvrthr12==.d | tvrtmn12==.d
	replace wrktrav12 = .r if tvrthr12==.r | tvrtmn12==.r | wrkple12==.r
	replace wrktrav12 = 1  if wrkple12==2
	replace wrktrav12 = 1  if activ12>=3 & activ12<=5		// Assumed worker vs. non-worker distinction is dealt with by EMP12
	replace wrktrav12 = 5 if wrkple12==3
	label define wrktrav12 5 "5__no fixed wrkplace", modify
	label var wrktrav12 "Travel time to work, grouped"
drop travtowk00 travwk04 travmins12 tvrthr12 tvrtmn12
	
	
	
/////////////////////////////
// HOURS OF WORK - added since v1, needed alongside income
mvdecode chours*00 cjsehrs00, mv(999=.r \ 998=.d)
egen wrkhours00 = rowtotal(chours100-chours400 cjsehrs00)
	replace wrkhours00 = . if missing(chours100) & missing(chours200) & missing(cjsehrs00)
	replace wrkhours00 = 1 if activ00>=3 & activ00<=5
egen wrkhours04 = rowtotal(chour104-chour404 cjsehs04)
	replace wrkhours04 = . if missing(chour104) & missing(chour204) & missing(cjsehs04)
	replace wrkhours04 = 1 if activ04>=3 & activ04<=5
egen wrkhours12 = rowtotal(chour112-chour412 cjsehs12)
	replace wrkhours12 = . if missing(chour112) & missing(chour212) & missing(cjsehs12)
	replace wrkhours12 = 1 if activ12>=3 & activ12<=5
foreach year in 00 04 12	{
	recode wrkhours`year' (1/29.9=1 "1_<30hrs") (30/44.9=2 "2_30-44hrs") (45/200=3 "3_45hrs+"), gen(wrkhoursG`year')
	label var wrkhoursG`year' "Working hours in 20`year', grouped, non-workers set to 1"
/**/						}
drop chour* cjsehrs00 cjsehs04 cjsehs12
	
	

/////////////////////////////
// TENURE - added since v1
recode tenure200 (1/3=1 "1_owner/occupier") (4=2 "2_rent") (5/7=3 "3_other") (9=.r)	, gen(housing00)
	label var housing00 "Housing tenure"
recode ten204    (1/3=1 "1_owner/occupier") (4=2 "2_rent") (5/7=3 "3_other") (9=.r)	, gen(housing04)
	label var housing04 "Housing tenure"
recode ten12     (1/3=1 "1_owner/occupier") (4=2 "2_rent") (5/7=3 "3_other") 		, gen(housing12)
	label var housing04 "Housing tenure"
drop tenure*00 ten*04 ten12



/////////////////////////////
// SMOKING - added since v1
* Smoking status
recode smoking00 (1/2=1 "1_doesn't smoke") (3=2 "2_occasional smoker") (4=3 "3_daily smoker") (8=.d) (9=.r), gen(currsmk00)
	label var currsmk00 "Current smoking status"
recode smokig04 (1/2=1 "1_doesn't smoke") (3=2 "2_occasional smoker") (4=3 "3_daily smoker") (8=.d) (9=.r), gen(currsmk04)
	label var currsmk04 "Current smoking status"
recode smokig12 (1/2=1 "1_doesn't smoke") (3=2 "2_occasional smoker") (4=3 "3_daily smoker") 			  , gen(currsmk12)
	label var currsmk12 "Current smoking status"
drop smoking00 smokig??
	
* Cigs/day among daily smokers
ren nofcigs00  	cigsday00
	replace cigsday00 = .r if cigsday00==999
	replace	cigsday00 = 0 if currsmk00<3
	label var cigsday00 "Cigarettes/day, non-daily smokers set to zero"
ren nfcigs04	cigsday04
	replace	cigsday04 = 0 if currsmk04<3
	label var cigsday04 "Cigarettes/day, non-daily smokers set to zero"
ren nfcigs12	cigsday12
	replace	cigsday12 = 0 if currsmk12<3
	label var cigsday12 "Cigarettes/day, non-daily smokers set to zero"
	
	

/////////////////////////////
// PARTNERSHIP STATUS - added since v1
* Renaming
ren b96032296 	marstat96
ren marstat00	marproxy00
ren marstat200	marstat00
* Recoding for consistency into 4 groups
recode ms12 (2 5=1 "1_married/civil partnership")(8=3 "3_single")(1 3 4 6=4 "4_sep/div/wid"), gen(cohab12)
	replace cohab12 = 2 if partp12==3 & cohab12~=1
	label define cohab12 2 "2_cohabiting (takes precedence over single or sep)", modify
recode ms00 ms04 (1=1 "1_ married") (2=2 "2_cohabiting") (3=3 "3_single")(4/6=4 "4_sep/div/wid") (9=.o), gen(cohab00 cohab04) label(cohab)
gen 		cohab96 = 1 if marstat96==2 | marstat96==3
	replace cohab96 = 2 if livngsit96==2 | (livngsit96==1 & missing(cohab96))
	replace cohab96 = 3 if marstat96==1 & livngsit96==3
	replace cohab96 = 4 if marstat96>=4 & marstat96<=6
	label values cohab96 cohab
foreach var in 96 00 04 12	{
	label var cohab`var'	"Cohabitation/marital status (dv)"
	/**/					}
drop marstat* marproxy* ms?? ms12 partp12
	
	
	
/////////////////////////////
// SELF-REPORTED HEALTH - added since v1
recode hlthgen00 (1/2=0 "0_excellent/good") (3/4=1 "1_fair/poor/v poor") (8=.d) (9=.r), gen(poorhlth00)	
	label var poorhlth00 "Poor SRHealth (note diff response options each year)"	
recode khlstt04 (1/2=0 "0_excellent/good") (3/5=1 "1_fair/poor/v poor"), gen(poorhlth04)
	label var poorhlth04 "Poor SRHealth (note diff response options each year)"	
mvdecode hlthgn12 loil12, mv(-9=.r\-8=.d\-1=.n)		// I think only necessary because I added this quite late
recode hlthgn12 (1/3=0 "0_excellent/very good/good") (4/5=1 "1_fair/poor"), gen(poorhlth12)
	label var poorhlth12 "Poor SRHealth (note diff response options each year)"	
drop hlthgen00 khlstt04	hlthgn12 
	
	
	
/////////////////////////////
// LSI - added since v1
recode lsiany200 (1=1) (2=0) (8=.d) (9=.r), gen(lsi00)
	label var lsi00 "Long-standing illness"
recode lsiany04 (1=1) (2=0), gen(lsi04)
	label var lsi04 "Long-standing illness"
recode loil12 (1=1) (2=0), gen(lsi12)
	label var lsi12 "Long-standing illness"
drop lsiany* loil12



/////////////////////////////
// EMOTIONAL SUPPORT - added since v1
recode emosup00 (1=1 "1_yes") (2=0 "0_no") (8=.d) (9=.r), gen(support00)
	label var support00 "Anyone could turn to for support (note diff qs in 2000 and 2004)"
recode nsup04 (0=0 "0_no") (1/11=1 "1_yes"), gen(support04)
	label var support04 "Anyone could turn to for support (note diff qs in 2000 and 2004)"
drop emosup* emosup00 nsup04



/////////////////////////////
// RELIGIOUS ATTENDANCE - added since v1
recode freqrelg00 (1=1 "1_weekly") (2/4=0 "0_<wkly"), gen(relweek00)
	replace relweek00 = 0 if religion00==1
	label var relweek00 "Attends religious service 1+/wk"
recode rnoweq04 (1=1 "1_weekly") (2/5=0 "0_<wkly"), gen(relweek04)
	replace relweek04 = 0 if rnowrl04==2 | rnowrl04==3
	label var relweek04 "Attends religious service 1+/wk"
/* 2012 can be slightly different - it was s/c PAPI, so people who said 'no religion' still had to say that they didn't
go to religious services.  Note that a tiny fraction of people who say they're attached to no religion do still go weekly
(0.3%), but this can be ignored rather than going back to pick up bb9scq22 */
recode scq2312 (1=1 "1_weekly")(2/5=0 "0_<wkly"), gen(relweek12)
	label var relweek12 "Attends religious service 1+/wk"
drop religion00 freqrelg00 rpasel04 rrelps04 rnowrl04 rnoweq04 scq2312


/////////////////////////////
// CURRENTLY PREGNANT - added since v1
gen pregnant00 = (prega00==5 | prega600==5)	& male==0	// prega00 should be the most recent pregnancy, but 1 person reports being pregnant in prega600 too - see the PDF file on pregnancy data
	label var pregnant00 "Currently pregnant"
egen pregnant04 = anymatch(preg1?04 preg2?04 preg3?04 preg4?04 preg5?04 preg6?04 preg7?04 preg8?04) if male==0, values(5)
	label var pregnant04 "Currently pregnant"
gen pregnant12 = (curprg==1 & male==0)
	label var pregnant12 "Currently pregnant"
drop prega*00 preg??04 curprg



/////////////////////////////
// ANY KIDS - added since v1
foreach yr in 00 04 12	{
	gen anykids0_5`yr'  = (tchild0_5`yr'>0)  if ~missing(tchild0_5`yr')
	gen anykids6_17`yr' = (tchild6_17`yr'>0) if ~missing(tchild6_17`yr')
/**/					}






	
	
**************************************************************
**************************************************************
**************************************************************
** Controls for 1986
**************************************************************
**************************************************************
**************************************************************

/////////////////////////////
// DRINKING BEHAVIOUR
recode alcfreq86 (1/3=1 "1_2+ times/wk") (4=2 "2_about 1/wk") (5=3 "3_about 1/mth") (6=4 "4_special occs only") (7=5 "5_never drink"), gen(alcfreqG86)
	label var alcfreqG86 "Frequency of drinking in past yr, grouped from ALCFREQ86"


	
/////////////////////////////
// SMOKING BEHAVIOUR
* Own smoking
recode smknumweek86 (1=1 "1_non smoker") (2/4=2 "2_1-10 cigs/wk") (5/6=3 "3_10-40 cigs/wk") (7/9=4 "4_40+ cigs/wk"), gen(smkgrp86)
	label var smkgrp86 "Num of cigs smoked, self-report from GH2"

* Parent's smoking behaviour
gen smkpar86 		= 3 if (smkfammom86==3 | smkfamdad86==3)
replace smkpar86 	= 2 if (smkfammom86==2 | smkfamdad86==2) & missing(smkpar86)
replace smkpar86 	= 1 if (smkfammom86==1 | smkfamdad86==1) & missing(smkpar86)
label var smkpar86 "Most frequent smoking among parents, 3-cat"

/* Not used due to missingness when using maternal reports
clonevar smkmum86 = smkmon86
	replace smkmum86 = 0 if smkmo86==4 | smkmo86==5
	label var smkmum86 "Maternal report of self(mother) cigs/day"
clonevar smkdad86 = smkhusbn86
	replace smkdad86 = 0 if smkhusb86==4 | smkhusb86==5
	label var smkdad86 "Maternal report of father cigs/day"
gen teensmk86 = smkcigtnm86
	replace teensmk86 = 0 if smkhabm86==4 | smkhabm86==5
	label var teensmk86 "Maternal report of teen cigs/day (dv)"
*/
	
	
/////////////////////////////
// DRUG TAKING
capture drop drug*
local drugvars "drgtgluP86 drgtcocP86 drgtherP86 drgtuppP86 drgtdowP86 drgtcanP86 drgtlsdP86"
sum `drugvars'
egen drugresp86 	= rowmiss(`drugvars')
	egen drugever86 	= anymatch(`drugvars'), values(2/3)
	egen druglstyr86	= anymatch(`drugvars'), values(4/5)	
gen druguse86 = 1	
	replace druguse86=2 if drugever86==1
	replace druguse86=3 if druglstyr86==1
	replace druguse86=. if drugresp>4
	capture label define druguse86 1 "1_Never used" 2 "2_Once or less in past yr" 3 "3_2+ times in past year", modify
	label values druguse86 druguse86
	label var druguse86 "Lifetime drug use (3-cat dv)"

	
/////////////////////////////
// STRICTNESS REVERSED
clonevar ptstrctN86O = ptstrctN86
replace ptstrctN86 = 8 - ptstrctN86
	capture label define ptstrctN86rev 1 "1_very free" 7 "7_very strict", modify
	label values ptstrctN86 ptstrctN86rev

	
/////////////////////////////
// PARENTAL CONTACT
egen parcontact86 = rowmin(thngsmum86 thngsdad86 thngspar86)
	label values parcontact86 gb8_1
	label var parcontact86 "Do things together with one/both parents (dv)"

	
/////////////////////////////
// TIME IN CARE
recode timecare00 (1/9=1 "1_spent any time in care") (else=0), gen(incare00)
	label var incare00 "Spent any time in care"
	

/////////////////////////////
// DELINQUENCY AT 16 - added after v1
unab dldvars: dld*
foreach var in `dldvars'	{
	recode `var' (6=0 "0_no") (5=1 "1_yes not in past year") (1=2 "2_once in past year") (2=3 "3_2-5 times in past yr")	///
		(3=4 "4_6-10 times in past yr") (4=5 "5_11+ times in past year"), gen(`var'R)
	/**/					}
egen delinqscore86 = rowmean(dld*R)
	egen delinqmiss  = rowmiss(dld*R)
	replace delinqscore86 = . if delinqmiss>4
	drop delinqmiss
alpha dld*R					// Cronbach's alpha = 0.8151 from 26 items, as the paper I'm taking this from says
drop dld*	
	

	
	
**************************************************************
**************************************************************
**************************************************************
** Dropping vars I'm unlikely to use
**************************************************************
**************************************************************
**************************************************************
	
drop height ht* weight wt* bmi*	// Consider if reviewers request it, but doesn't seem essential (despite Massin-Kopp's argument)
drop epolengG86-epcseo10G86		// R's exam scores at 16
drop pqtrdapp86-pqnotkno86		// R's parents' qualifications (but yr left FTed is available)
drop cannabis00-methad00 dope*	// Drug use at older ages
drop ghq900 efficac200 mhprobs?00 livstwrs96 sepc00 fameats00-mapadivb00 evercar?00	numsusps00 numexcls00 ///
	truant00 police?00 court00 lpara04 maliv04 carejy04 xso0??04		// Misc vars not needed 
drop *86O						// Original versions of recoded vars
drop otimny12 sepa12 wrkple12 nualc12 
	
save temp/postsecondclean, replace
	
