/* KENZO: To get the highest education variable, I will translate the SPSS code found in the document 
"THE DESIGN AND CONDUCT OF THE 1999-2000 SURVEYS OF THE NATIONAL CHILD DEVELOPMENT STUDY AND THE 1970 BRITISH COHORT STUDY"
at http://www.esds.ac.uk/doc/5578/mrdoc/pdf/user_guide_1999-2000_vol_1_design_and_conduct_of_the_1999-2000_surveys.pdf
page 271 according to the PDF page numbering (Appendix 7).

BB
1. Kenzo's code had some mistakes in it (obvious if you checked the dvs) that I've corrected 23/7/2013, around the use of 
ELSE statements in SPSS - this is under the highest qual vars below (see notes there
2. Note that this is the first of the two parts of supplied code, and not the Samantha Parsons code which is designed 
to be comparable to NCDS
*/

		/* ************************* DESCRIPTION OF PROGRAM ************************************.
		* This program derives academic and qualifications using the 2000 data only.
		* It defines a set of binary variables showing whether an individual has a particular qualification.
		* These variables could then be used to devise various typologies for training .
		* We also derive the highest qualification below.
		* All variables based on data from the 2000 surveys end in 00.
		* The interpretation of the results differs across observations.
		************************ DEFINITION OF VARIABLES ***********************************************.
		* There are 2 relevant questions.
		* The first asks 'Have you obtained any of the qualifications on this card since xx'.
		* If the respondent has the qualification, the second question asks 'How many did you get?'
		eg 'How many GCE O-levels did you get ..?' 'How many City and Guilds quals have you obtained ..'.
		* Where possible, we have defined the variables using the responses to the questions asking
		how many qualifications of a particular type the respondent has.
		* Often the respondent says none. We could interpret this as follows. The respondent said
		'I have the qualification' when asked the first question but on reflection realised that they did
		not have it. This interpretation is strengthened by the fact that the information on all types of
		qualification is collected first.
		* Suppose the Cohort Member (CM) says I have a GCSE, a GCE and a CSE.
		* When the interviewer goes through the number of qualifications (one qualfication at a time) the
		CM realises that the GCSE was GCE and one of the CCEs was a GCE.
		* The CM may know that he/she has a qualification but does not know how many O-levels, CSEs etc
		he/she has. The CM may respond 98, 99 but 0 seems unlikely if they have the qualification.
		* 0 is a genuine response. The feed question for certain qualifications refers to all grades while the
		'how many
		questions' refer to different ranges of grades. Consider somebody who has 8 GCSEs all at grade A.
		They will say they have a gcse in response to the feeder question, but then answer 8 for the number of grade
		A-Cs (edgcse1) and 0 to for the number of grade D-Es (edgcse2) .
		* The code below is easily amended to reflect the programmer's preferences.
		* Typically the response 'I have none of those qualification' (number equals 0) and the missing values
		for number of qualifications (8,9,98,99) have to be changed.
		* We have intepreted 8 and 98 as 'Do not know' and 9 and 99 as 'Not Applicable'.
		* We have set 8 and 98 equal to 1 (ie denoting possession of the qualification) suggesting that these
		values reflect an inability to remember the exact number of qualifications obtained.
		* We have set 9 and 99 equal to 0 suggesting that the respondent has considered the case further
		and decided that he/she does not have the qualification.
		* The missing value dummies set 9 for edquals2 and vocqual equal to 0.
		* Not Applicable is an odd response but it seems very close to saying 'No' I do not have any of the
		quals.
		******************** INTERPRETATION OF VARIABLES ****************************************.
		* The BCS70 qualifications are collected at ages 26 and 30. The age 16 questions refer to
		future examinations (ie the survey took place before the exams were taken).

		* This program uses the age 30 data (from the 2000 survey). The routing questions ask 'Have you
		obtained any of the qualifications on this card since April 1986'. Since most school exams were
		taken in the summer, it is therefore a summary of 'have you ever had this qualification'. It could
		perhaps be improved by comparing it to the age 26 data but there are differences in the form of
		the question and the method of collecting the data.
		* The age 26 survey was a postal survey with a smaller sample than the age 30 sample and there is
		less detail in the questions asked at 26.
		* NCDS has regularly collected information on qualifications. The questions in 2000 asked
		'whether the qualification has been obtained since the age of 33' for individuals in NCDS V and
		'whether the qualification has been obtained since the age of 23' for individuals not in NCDS V.
		* It is therefore a good summary of 'have you got this qualification since you were x years old'.
		******************** EXAMPLE AND AN IMPLICATION OF OUR APPROACH
		***************************.
		* Consider the following code for the variable odeg00=1 if he/she has any other degree level
		qualifications .
		* We generate this from the answer to 'how many other degree level qualifications do you have?'
		(numothdg)
		using the following code.
		* recode numothdg (missing=0) (0=0) (98=1)(99=0) (1 thru hi=1) into odeg00 .
		* variable labels odeg00 "Other degree level quals such as graduate membership of professional
		institutes".
		* A crosstabs of numothdg by odeg00 shows that there 99 zeros for numothdeg that give odeg00=0
		and
		1 value of 98 that gives odeg00=1.
		* We could have defined the alternative measure, ALTodeg, based on the question 'Do you have any
		of
		the following qualifications?' If the individual has 'other degree level qualifications', these are
		recorded
		as the value 9 in one of the variables edqtyp14 to edqtyp26. The code for this variable is below.
		* gen ALTodeg=0 .
		* if (any(9,edqtyp14,edqtyp15,edqtyp16,edqtyp17,edqtyp18,edqtyp19,edqtyp20,edqtyp21,
		edqtyp22,edqtyp23,edqtyp24,edqtyp25,edqtyp26) ) ALTodeg=1 .
		* A crosstabs of ALTodeg by odeg00 shows that there are 99 respondents with ALTodeg not equal
		odeg00
		corresponding to the 99 zeros for numothdeg . This is a large number since there are 963
		observations
		with odeg00=1.
		* Many people have used the definition similar to ALTodeg rather than the present one.
		********************* MISSING VALUES ************************************.
		* We begin by giving missing values the value 0. We later adjust the data for missing values.
		* Some analysis below shows that there are few genuinely missing values. The feed questions are
		'Have you obtained any of the qualifications on this card? with separate cards for educational and
		vocational questions. The answers to these questions are contained in edquals2 and vocqual.
		* (Be careful as there are variables with similar names for the proxy returns.) .
		* The possible answers to the feed questions are Yes, No, 8, 9, missing.
		* We treat an answer of Yes or No as saying that we have information on whether the interviewee has
		one or more of the qualifications.
		* The same 66 observations have missing values for both the educational and vocational questions.
		* A further 50 of the educational and 44 of the vocational answers are 8 or 9.

		* There are 28 values of 8 or 9 for both the educational and vocational questions.
		* The variables allmiss, acamiss and vocmiss capture the missing answers.
		* No respondents have 8 or 9 for the feeder question but subsequently report a qualification.
		* (Based on edqtyp14 and voctyp12 only).
		********************************** PROXY INTERVIEWS *******************************.
		* We have not picked up the observations (perhaps 26) given for proxy interviews.
		* Proxy returns occur when someone completed the form on behalf of the CM.
		* The variable identifying a proxy interview is IntWho in the Household Grid and Housing
		but we did not extract that information and it is not used below.
		* A measure (proxy=1) of whether the form is completed by a proxy is computed below .
		* From the data available to us at present, there are 26 interviews completed by proxy.
		* Be careful because many of the variables only refer to proxy interview
		eg agelfted, edquals and vocquals are for proxies,
		agelfte2, edquals2 and vocqual are for interviews completed by CMs.
		* edqtyp01 to edqtyp13, voctyp01 to voctyp11 are completed by proxies.
		* edqtyp14 to edqtyp26, voctyp12 to voctyp22 are completed by CMs .
		*********************************** GCSE ********************************************.
		* An apparently large proportion of the BCS70 cohort claim to have done GCSEs. They
		were one of the last cohorts to do GCE/CSE at school. This program does not resolve
		the issues raised by this although it seems clear that some respondents have not
		identified the exams that they took properly.
		********************* ADAPTING THE CODE **********************************************.
		* The code be could be simplified by merging the recode and other commands. For example,
		the opening code below could be written as .
		* recode edgcse1 edgcse2 (missing=0) (0=0) (98=1) (99=0) (1 thru hi =1) into gcsehi00 gcselo00 .
		* variable labels csehi00 "Has CM obtained one or more CSEs at grade 1?"
		* / cselo00 "Has CM obtained one or more CSEs at grades 2 to 5?".
		* (Be careful. Some variables use 9 as a missing value but 9 is a legitimate value for other
		variables.) .
		* The program is divided into sections because the PC on which it was developed could not
		handle the whole lot in one go.
		*/
		*********************************************************************************************.
		***************************** PROGRAM STARTS *************************************.
		*********************************************************************************************.
		**********************************************************************************************.
		******************************* LOAD DATA **********************************************.
		**********************************************************************************************.

		
		
		
*************************** GCSE, O-LEVELS, CSE ***********************************.
recode edgcse100 (98=1) (99=0) (1/90 =1) (missing=0), gen(gcsehi00)
recode edgcse200 (98=1) (99=0) (1/90 =1) (missing=0), gen(gcselo00)
	* In these cases, hi(90) is 13 and 9 respectively.
	label variable gcsehi00 "Has CM obtained one or more GCSEs at grades A to C ?"
	label variable gcselo00 "Has CM obtained one or more GCSEs at grades D to E ?"

recode edolev100 (98=1) (99=0) (1/90=1) (missing=0), gen(olevhi00)
recode edolev200 (98=1) (99=0) (1/90=1) (missing=0), gen(olevlo00)
	* Hi(90) is 15 and 11.
	label variable olevhi00 "Has CM obtained one or more O levels at grades A to C?"
	label variable olevlo00 "Has CM obtained one or more O levels at grades D to E?"
	
recode edcse100 (98=1) (99=0) (1/90=1) (missing=0), gen(csehi00)
recode edcse200 (98=1) (99=0) (1/90=1) (missing=0), gen(cselo00)
	* Hi(90) is 12 and 11.
	label variable csehi00 "Has CM obtained one or more CSEs at grade 1?"
	label variable cselo00 "Has CM obtained one or more CSEs at grades 2 to 5?"

************** AS AND A-LEVELS *****************************.
recode edasl100 (98=1) (99=0) (1/90=1) (missing=0), gen(aslhi00)
recode edasl200 (98=1) (99=0) (1/90=1) (missing=0), gen(asllo00)
* Hi is 9 and 7.
	label variable aslhi00 "Has CM obtained one or more AS levels at grades A to C?"
	label variable asllo00 "Has CM obtained one or more AS levels at grades D to G?"
	
gen naslev00=edasl1
recode naslev00 (98=1) (99=0) (missing=0)
	label variable naslev00 "Number of AS level passes at grade A-C"

recode edgcasl100 (98=1) (99=0) (1/90=1) (missing=0), gen(alevhi00)
recode edgcasl200 (98=1) (99=0) (1/90=1) (missing=0), gen(alevlo00)
	gen alev00=alevhi00 + alevlo00
recode alev00 (1 2=1)
	label variable alevhi00 "Has CM obtained one or more A levels at grades A to C?"
	label variable alevlo00 "Has CM obtained one or more A levels at grades D to E?"
	label variable alev00 "Has CM obtained any A level passes at any grade?"
gen t1=edgcasl1
gen t2=edgcasl2
recode t1 (98=1) (99=0) (missing=0)
recode t2 (98=1) (99=0) (missing=0)
* Someone with a 98 or 99 only gets 1 A-level
gen nalev00 = t1+t2
	label variable nalev00 "Number of A level passes at any grade"

********************** SCOTTISH SCHOOL QUALIFICATIONS *************
*freq edscot1 edscot2 edscot3 edscot4 edscot5 edscot6 .

*page 276
* The Scottish qualifications are in edscot1 to edscot6 although edscot5 and edscot6 only have missing values.
* This is not obvious from documentation.
gen scotlo00=0
gen scot200=0
gen scot300=0
gen scot400=0
gen scot500=0
gen scot600=0
	label variable scotlo00 "Has CM obtained Scottish SCE standard grades 4-5 or equivalent?"
	label variable scot200  "Has CM obtained Scottish SCE standard grades 1-3 or equivalent?"
	label variable scot300  "Has CM obtained Scottish SUPE-SLC lower or ordinary grade?"
	label variable scot400  "Has CM obtained Scottish SCE-SUPE-SLC higher grade or equivalent?"
	label variable scot500 "Has CM obtained Scottish Certificate of 6th Year Studies?"
	label variable scot600 "Has CM obtained other Scottish school qualification?"
* Scottish higher equivalent to A level in IFS definitions.
replace scotlo00=1 if edscot1==1 | edscot2==1 | edscot3==1 | edscot4==1
replace scot200 =1 if edscot1==2 | edscot2==2 | edscot3==2 | edscot4==2
replace scot300 =1 if edscot1==3 | edscot2==3 | edscot3==3 | edscot4==3
replace scot400 =1 if edscot1==4 | edscot2==4 | edscot3==4 | edscot4==4
replace scot500 =1 if edscot1==5 | edscot2==5 | edscot3==5 | edscot4==5
replace scot600 =1 if edscot1==6 | edscot2==6 | edscot3==6 | edscot4==6

************** DEGREES ************************
* Is 9 the missing value for numdeg.
recode numdeg00 (9=0) (1/90=1) (missing=0), gen(deg00)
	* Hi is 4.
	label variable deg00 "Has CM obtained a degree?"
recode numothdg00 (98=1) (99=0) (1/90=1) (missing=0), gen(odeg00)
	* hi = 6.
	label variable odeg00 "Other degree level quals such as graduate membership of professional institutes"

gen ALTodeg=0
	replace ALTodeg=1 if edqtyp1400==9 | edqtyp1500==9 | edqtyp1600==9 | edqtyp1700==9 ///
					   | edqtyp1800==9 | edqtyp1900==9 | edqtyp2000==9 | edqtyp2100==9 
*crosstabs ALTodeg by odeg00 .
*crosstabs numothdg by odeg00 .
recode numhghdg (98=1) (99=0) (1/90=1) (missing=0), gen(hdeg00)
	*hi = 3, no 98 or 99.
	label variable hdeg00 "Has CM obtained a higher degree?"
	
**************** NURSING, DIPLOMAS, PGCE **************.
*There are 3 values for edqtyp21, all the values for edqtyp22 to edqtyp26 are missing.
gen dip00=0
	replace dip00=1 if edqtyp14==7 |edqtyp15==7 |edqtyp16==7 |edqtyp17==7 |edqtyp18==7 ///
		 |edqtyp19==7 |edqtyp20==7 |edqtyp21==7 |(numotht > 0 & numotht < 15)
*page 277
	label variable dip00 "Diploma-Certificate-Teacher Training Qual (not pgce) in Higher Ed"

* 357 have 1 teacher training qualification. 1 person has 12.
recode numparam (98=1) (99=0) (1/90=1) (missing=0), gen(nurse00)
	*hi=15 No 98 or 99.
	label variable nurse00 "Has CM obtained any nursing or paramedic qualifications?"

gen pgce00=0
	replace pgce00=1 if edqtyp14==12 |edqtyp15==12 |edqtyp16==12 |edqtyp17==12 |edqtyp18==12 ///
					   |edqtyp19==12 |edqtyp20==12 |edqtyp21==12
	label variable pgce00 "Has CM obtained a PGCE or other postgraduate certificate in HE?"

*************************************************************************************************************.
**************************** FIRST BLOCK FOR RUNNING PROGRAM ******************* .
*************************************************************************************************************.
********* ONC or OND AND HNC or HND ********************.
recode voconc (98=1) (99=0) (1/90=1) (missing=0), gen(oncond00)
	* hi=7 .
	label variable oncond00 "Does CM have ONC or OND?"
recode vochnc (9=0) (98=1) (99=0) (1/90=1) (missing=0), gen(hnchnd00)
	* hi=4. One value of 9.
	label variable hnchnd00 "Does CM have HNC or HND?"
***** BTECS *****.
gen btec100=0
gen btec200=0
	label variable btec100 "Does CM have a BTEC etc First-General Certificate?"
	label variable btec200 "Does CM have a BTEC etc First-General Diploma?"
gen btec300=0
gen btec400=0
	label variable btec300 "Does CM have a BTEC etc National Certificate Diploma?"
	label variable btec400 "Does CM have a BTEC etc Higher Certificate Diploma?"
gen btec500=0
	label variable btec500 "Does CM have other BTEC qualification?"

	replace btec100=1 if bteclev00==1 |bteclev200==1 |bteclev300==1 |bteclev400==1 |bteclev500==1 ///
		|bteclev600==1 |bteclev700==1 |bteclev800==1 |bteclev900==1
	replace btec200=1 if bteclev00==2 |bteclev200==2 |bteclev300==2 |bteclev400==2 |bteclev500==2 ///
		|bteclev600==2 |bteclev700==2 |bteclev800==2 |bteclev900==2
	replace btec300=1 if bteclev00==3 |bteclev200==3 |bteclev300==3 |bteclev400==3 |bteclev500==3 ///
		|bteclev600==3 |bteclev700==3 |bteclev800==3 |bteclev900==3
	replace btec400=1 if bteclev00==4 |bteclev200==4 |bteclev300==4 |bteclev400==4 |bteclev500==4 ///
		|bteclev600==4 |bteclev700==4 |bteclev800==4 |bteclev900==4
* page 278
	replace btec500=5 if bteclev00==5 |bteclev200==5 |bteclev300==5 |bteclev400==5 |bteclev500==5 ///
		|bteclev600==5 |bteclev700==5 |bteclev800==5 |bteclev900==5
	* Only one observation in each of bteclev9 to bteclev15. All have first or general certificate.
	* Some values equal to 9 eg 89 observations with 9 for bteclev.
***** CITY AND GUILDS *****.
gen city100=0
gen city200=0
gen city300=0
gen city400=0
gen city500=0
	label variable city100 "Does CM have a City and Guilds Part 1 "
	label variable city200 "Does CM have a City and Guilds Part2 or Craft or Intermediate"
	label variable city300 "Does CM have a City and Guilds Part3 or Final or Advanced Craft"
	label variable city400 "Does CM have a City and Guilds Part4 or Career Extension or Full technological"
	label variable city500 "Does CM have a City and Guilds Other C&G qualification"

	replace city100=1 if citylev00==1 |citylev200==1 |citylev300==1 |citylev400==1 |citylev500==1 ///
					   |citylev600==1 |citylev700==1 |citylev800==1 |citylev900==1
	replace city200=1 if citylev00==2 |citylev200==2 |citylev300==2 |citylev400==2 |citylev500==2 ///
					   |citylev600==2 |citylev700==2 |citylev800==2 |citylev900==2
	replace city300=1 if citylev00==3 |citylev200==3 |citylev300==3 |citylev400==3 |citylev500==3 ///
					   |citylev600==3 |citylev700==3 |citylev800==3 |citylev900==3
	replace city400=1 if citylev00==4 |citylev200==4 |citylev300==4 |citylev400==4 |citylev500==4 ///
					   |citylev600==4 |citylev700==4 |citylev800==4 |citylev900==4
	replace city500=1 if citylev00==5 |citylev200==5 |citylev300==5 |citylev400==5 |citylev500==5 ///
					   |citylev600==5 |citylev700==5 |citylev800==5 |citylev900==5
**** RSA ****************.
gen rsa100=0
gen rsa200=0
gen rsa300=0
gen rsa400=0
gen rsa500=0
	label variable rsa100 "Does CM have RSA certificate?"
	label variable rsa200 "Does CM have RSA First Diploma?"
	label variable rsa300 "Does CM have RSA Advanced Diploma or Certificate?"
	label variable rsa400 "Does CM have RSA Higher Diploma"
	label variable rsa500 "Does CM have other RSA qualification?"
	replace rsa100=1 if rsalev00==1 |rsalev200==1 |rsalev300==1 |rsalev400 ==1 |rsalev500 ==1 ///
	    |rsalev600==1 |rsalev700==1 |rsalev800==1 |rsalev900==1 |rsalev1000==1 |rsalev1100==1 |rsalev1200==1
	replace rsa200=1 if rsalev00==2 |rsalev200==2 |rsalev300==2 |rsalev400 ==2 |rsalev500 ==2 ///
	    |rsalev600==2 |rsalev700==2 |rsalev800==2 |rsalev900==2 |rsalev1000==2 |rsalev1100==2 |rsalev1200==2
	replace rsa300=1 if rsalev00==3 |rsalev200==3 |rsalev300==3 |rsalev400 ==3 |rsalev500 ==3 ///
	    |rsalev600==3 |rsalev700==3 |rsalev800==3 |rsalev900==3 |rsalev1000==3 |rsalev1100==3 |rsalev1200==3
* page 279
	replace rsa400=1 if rsalev00==4 |rsalev200==4 |rsalev300==4 |rsalev400 ==4 |rsalev500 ==4 ///
	    |rsalev600==4 |rsalev700==4 |rsalev800==4 |rsalev900==4 |rsalev1000==4 |rsalev1100==4 |rsalev1200==4
	replace rsa500=1 if rsalev00==5 |rsalev200==5 |rsalev300==5 |rsalev400 ==5 |rsalev500 ==5 ///
	    |rsalev600==5 |rsalev700==5 |rsalev800==5 |rsalev900==5 |rsalev1000==5 |rsalev1100==5 |rsalev1200==5
	* rsalev10 to rsalev12 only have 1 observation each. All values are for first diplomas (2).
**** PITMANS *******
* Pitmans are only in the 2000 data.
gen pit100=0
gen pit200=0
gen pit300=0
gen pit400=0
	label variable pit100 "Does CM have a Pitmans level 1?"
	label variable pit200 "Does CM have a Pitmans level 2?"
	label variable pit300 "Does CM have a Pitmans level 3?"
	label variable pit400 "Does CM have other Pitmans qualification?"
	replace pit100=1 if pitlev00==1 |pitlev200==1 |pitlev300==1 |pitlev400==1 |pitlev500==1 |pitlev600==1 |pitlev700==1
	replace pit200=1 if pitlev00==2 |pitlev200==2 |pitlev300==2 |pitlev400==2 |pitlev500==2 |pitlev600==2 |pitlev700==2
	replace pit300=1 if pitlev00==3 |pitlev200==3 |pitlev300==3 |pitlev400==3 |pitlev500==3 |pitlev600==3 |pitlev700==3
	replace pit400=1 if pitlev00==4 |pitlev200==4 |pitlev300==4 |pitlev400==4 |pitlev500==4 |pitlev600==4 |pitlev700==4
		* pitlev7 has one observation with a value of level 2.
******** NVQ *************.
*nvqs (current sweep only) .
gen nvq100=0
gen nvq200=0
gen nvq300=0
gen nvq400=0
gen nvq500=0
gen nvq600=0
gen nvq700=0
gen nvq800=0
	label variable nvq100 "Does CM have an NVQ at Level 1?"
	label variable nvq200 "Does CM have an NVQ at Level 2?"
	label variable nvq300 "Does CM have an NVQ at Level 3?"
	label variable nvq400 "Does CM have an NVQ at Level 4?"
	label variable nvq500 "Does CM have an NVQ at Level 5?"
	label variable nvq600 "Does CM have an NVQ at Level 6?"
	label variable nvq700 "Does CM have Trusts towards NVQ-SVQ?"
	label variable nvq800 "Does CM have other NVQ?"
	replace nvq100=1 if nvqlev00==1 |nvqlev200==1 |nvqlev300==1 |nvqlev400==1 |nvqlev500==1 |nvqlev600==1
	replace nvq200=1 if nvqlev00==2 |nvqlev200==2 |nvqlev300==2 |nvqlev400==2 |nvqlev500==2 |nvqlev600==2
	replace nvq300=1 if nvqlev00==3 |nvqlev200==3 |nvqlev300==3 |nvqlev400==3 |nvqlev500==3 |nvqlev600==3
	replace nvq400=1 if nvqlev00==4 |nvqlev200==4 |nvqlev300==4 |nvqlev400==4 |nvqlev500==4 |nvqlev600==4
* page 280
	replace nvq500=1 if nvqlev00==5 |nvqlev200==5 |nvqlev300==5 |nvqlev400==5 |nvqlev500==5 |nvqlev600==5
	replace nvq600=1 if nvqlev00==6 |nvqlev200==6 |nvqlev300==6 |nvqlev400==6 |nvqlev500==6 |nvqlev600==6
	replace nvq700=1 if nvqlev00==7 |nvqlev200==7 |nvqlev300==7 |nvqlev400==7 |nvqlev500==7 |nvqlev600==7
	replace nvq800=1 if nvqlev00==8 |nvqlev200==8 |nvqlev300==8 |nvqlev400==8 |nvqlev500==8 |nvqlev600==8
		*nvqlev7 to nvqlev10 have no values.
****** GNVQ *****************.
* gnvqs (current sweep only)
gen gnvq100=0
gen gnvq200=0
gen gnvq300=0
gen gnvq400=0
label variable gnvq100 "Does CM have GNVQ Foundation?"
label variable gnvq200 "Does CM have GNVQ Intermediate?"
label variable gnvq300 "Does CM have GNVQ Advanced?"
label variable gnvq400 "Does CM have other GNVQ qualification?"
	replace gnvq100=1 if gnvlev00==1 |gnvlev200==1 |gnvlev300==1
	replace gnvq200=1 if gnvlev00==2 |gnvlev200==2 |gnvlev300==2
	replace gnvq300=1 if gnvlev00==3 |gnvlev200==3 |gnvlev300==3
	replace gnvq400=1 if gnvlev00==4 |gnvlev200==4 |gnvlev300==4	
		*gnvlev4 and gnvlev5 have no values.

*** OTHER QUALIFICATIONS *************
recode vocappr00 (98=1) (99=0) (1/90=1) (missing=0), gen(appren00)
	* hi is 7.
	label variable appren00 "Has CM obtained any recognised trade apprentice qualifications?"
recode vochgv00 (98=1) (99=0) (1/90=1) (missing=0), gen(hgv00)
	* hi is 3.
	label variable hgv00 "Has CM obtained at least one hgv qualification?"
recode vocoth00 (98=1) (99=0) (1/90=1) (missing=0), gen(othvoc00)
	* hi is 15.
	label variable othvoc00 "Has CM obtained at least one other vocational qualification?"

********************************************************************************************.
********************** MISSING VALUE ANALYSIS **********************************.
********************************************************************************************.
* edquals2, vocqual 1 ='Yes' 2='No' .
/* We argue that if initial feeder questions (edquals2, vocqual) are answered 'properly' then
we know whether the individual has a qualification or not. If the answer is missing or
'do not know' then we do not know. The code below sets all the educational qualifications
to missing if edquals is not answered Yes or No or NA and all the vocational qualifications to
missing if vocqual is not answered Yes or No or 'Not Applicable'.*/

* page 281

recode edquals200 (2=0) (1=0) (8=1) (9=0) (missing=2), gen(acamiss)
	label variable acamiss "Dummy for missing value for do you have an educational qualification"
		label define notmiss_dk_miss 0 "not missing" 1 "8 do not know" 2 "missing"
			label values acamiss notmiss_dk_miss

recode vocqual00 (1=0) (2=0) (8=1) (9=0) (missing=2), gen(vocmiss)
* vocmiss adjusted for nurse00 (nurse00 appears as an educational qualification) below.
	label variable vocmiss "Dummy for missing value for do you have a vocational qualification"
		label values vocmiss notmiss_dk_miss
gen 		allmiss=0 if (vocmiss==0 & acamiss==0)
	replace allmiss=1 if (vocmiss==1 & acamiss==0)
	replace allmiss=2 if (vocmiss==0 & acamiss==1)
	replace allmiss=3 if (vocmiss==1 & acamiss==1)
	replace allmiss=4 if (vocmiss==2 & acamiss==2)
		label variable allmiss "Missing values, Do you have any of these qualifications?"
		label define miss_voc_educ 0 "not missing" 1 "8 vocat quals, not missing for educ quals" 2 "vocat quals not missing, 8 for educ quals" 3 "8 for both vocat and educ quals" 4 "missing for both vocational & educational quals"
			label values allmiss miss_voc_educ

****** Set missing values **************
** I could have avoided the code in the next foreach if I would have replaced here by missing values (=.). However, I am doing this unnecessary step to be consistent with the SPSS code
replace gcsehi00 =-9 if acamiss>0
replace gcselo00 =-9 if acamiss>0
replace olevhi00 = -9 if acamiss>0
replace olevlo00 = -9 if acamiss>0
replace csehi00 = -9 if acamiss>0
replace cselo00 = -9 if acamiss>0
replace aslhi00 = -9 if acamiss>0
replace asllo00 = -9 if acamiss>0
replace naslev00 = -9 if acamiss>0
replace alevhi00 = -9 if acamiss>0
replace alevlo00 = -9 if acamiss>0
replace alev00 = -9 if acamiss>0
replace nalev00 = -9 if acamiss>0
replace scotlo00 = -9 if acamiss>0
replace scot200 = -9 if acamiss>0
replace scot300 = -9 if acamiss>0
replace scot400 = -9 if acamiss>0
replace scot500 = -9 if acamiss>0
replace scot600 = -9 if acamiss>0
replace dip00 = -9 if acamiss>0
replace deg00 = -9 if acamiss>0
replace odeg00 = -9 if acamiss>0
replace dip00 = -9 if acamiss>0
replace hdeg00 = -9 if acamiss>0
replace nurse00 = -9 if acamiss>0
replace pgce00 = -9 if acamiss>0
* page 282
	* Kenzo got wrong the following line - he had it down as nurse00=1 if vocmiss==0...
	replace vocmiss=0 if nurse00==1  	// nurse is a vocational qualification under some typologies eg nvq but educational here.
replace oncond00 =-9	if vocmiss>0 
replace hnchnd00 =-9	if vocmiss>0
replace btec100=-9		if vocmiss>0
replace btec200=-9		if vocmiss>0
replace btec300=-9		if vocmiss>0
replace btec400=-9		if vocmiss>0
replace btec500=-9		if vocmiss>0
replace city100 =-9		if vocmiss>0
replace city200 =-9		if vocmiss>0
replace city300 =-9		if vocmiss>0
replace city400 =-9		if vocmiss>0
replace city500 =-9		if vocmiss>0
replace rsa100 = -9		if vocmiss>0
replace rsa200 =-9		if vocmiss>0
replace rsa300 =-9		if vocmiss>0
replace rsa400 =-9		if vocmiss>0
replace rsa500 =-9		if vocmiss>0
replace pit100 =-9		if vocmiss>0
replace pit200 =-9		if vocmiss>0
replace pit300 =-9		if vocmiss>0
replace pit400 =-9		if vocmiss>0
replace nvq100 =-9		if vocmiss>0
replace nvq200 =-9		if vocmiss>0
replace nvq300 =-9		if vocmiss>0
replace nvq400 =-9		if vocmiss>0
replace nvq500 =-9		if vocmiss>0
replace nvq600 =-9		if vocmiss>0
replace nvq700 =-9		if vocmiss>0
replace nvq800 =-9		if vocmiss>0
replace gnvq100 =-9		if vocmiss>0
replace gnvq200 =-9		if vocmiss>0
replace gnvq300 =-9		if vocmiss>0
replace gnvq400 =-9		if vocmiss>0
replace appren00=-9		if vocmiss>0
replace hgv00 =-9		if vocmiss>0
replace othvoc00 =-9	if vocmiss>0

foreach varname in gcsehi00	gcselo00	olevhi00	olevlo00	csehi00	cselo00	aslhi00	asllo00	naslev00	alevhi00	alevlo00	alev00	nalev00	scotlo00	scot200	scot300	scot400	scot500	scot600	dip00	deg00	odeg00	dip00	hdeg00	nurse00	pgce00	oncond00	hnchnd00	btec100	btec200	btec300	btec400	btec500	city100	city200	city300	city400	city500	rsa100	rsa200	rsa300	rsa400	rsa500	pit100	pit200	pit300	pit400	nvq100	nvq200	nvq300	nvq400	nvq500	nvq600	nvq700	nvq800	gnvq100	gnvq200	gnvq300	gnvq400	appren00 hgv00	othvoc00{
	replace `varname'=. if `varname'==-9
	}

gen proxy = 0
	replace proxy=1 if edquals00>0
		* if (vocquals gt 0) proxy1 =1 not needed as proxy = proxy1.
	label variable proxy "Was interview completed by a proxy"
	* Acamiss=vocmiss=1 when proxy=1 so proxy 'accounts' for 26 of the missing values.
gen acamiss1=0
gen vocmiss1=0
	replace acamiss1=1 if (missing(edqtyp14) &missing(edqtyp15) &missing(edqtyp16) &missing(edqtyp17) &missing(edqtyp18) &missing(edqtyp19) &missing(edqtyp20) &missing(edqtyp21))
	replace vocmiss1=1 if (missing(voctyp12) &missing(voctyp13) &missing(voctyp14) &missing(voctyp15) &missing(voctyp16) &missing(voctyp17) &missing(voctyp18))

********** GOVERNMENT TRAINING SCHEMES **************.
recode numyts00 (98=1) (99=0) (1/90=1) (missing=0), gen(yts00)
	* hi is 15.
	label variable yts00 "Has CM done a YTS course?"
recode numgov00 (98=1) (99=0) (1/90=1) (missing=0), gen(gov00)
	* hi is 15.
	label variable gov00 "Has CM done another gov course (including New Deal)?"
recode numap00  (98=1) (99=0) (1/90=1) (missing=0), gen(modapp00)
	* hi is 3.
	label variable modapp00 "Has CM done a modern apprenticeship?"

******************************************************************************************************.
********************** SECOND BLOCK WHEN RUNNING PROGRAM **********************.
******************************************************************************************************.
************* OTHER COURSES ******************************.
recode numfqual00 (98=1) (99=0) (1/90=1) (missing=0), gen(nfail00)
	*Hi =11.
	label variable nfail00 "Number of courses started where CM did not obtain the qualification"
recode numac00 	(98=1) (99=0) (1/90=1) (missing=0), gen(access00)
	* hi is 10.
	label variable access00 "Has CM done an access course?"
gen workc00=numwrktr00
	recode workc00 (98=1) (99=0) (missing=0) /*don't understand why here there is no (1/90=1). Ben, do you get why?*/
* max is 30.
	label variable workc00 "Number of other work related courses"

*************** NON WORK RELATED COURSES ****************.
gen leis00=numleis00
	recode leis00 (98=1) (99=0) (missing=0)
	* max is 15.
	label variable leis00 "Number of courses for interest or leisure"
* page 284
**** READING, WRITING AND MATHS COURSES ********** .
recode numread00 (98=1) (99=0) (3/90=3) (missing=0), gen(read00)
	* max is 11.
	label variable read00 "Number of courses to improve reading"
recode numwrite00 (98=1) (99=0) (3/90=3) (missing=0), gen(write00)
	* max is 11.
	label variable write00 "Number of courses to improve writing"
* creative writing ?.
recode nummaths00 (98=1) (99=0) (3/90=3) (missing=0), gen(maths00)
	* max is 15.
	label variable maths00 "Number of courses to improve maths"
	label define three_or_more 3 "3 or more"
		label values read00 write00 maths00 three_or_more
*** THERE IS A LOT ABOUT CURRENT COURSES THAT WE HAVE NOT USED ***********.
*******************************************************************************************************.
********************* DUMMIES FOR GROUPS OF QUALIFICATIONS *********************.
*******************************************************************************************************.
************* HAS CM OBTAINED A PARTICULAR ACADEMIC QUALIFICATION? ************.

gen aca000=-9 if acamiss> 0
gen aca100=-9 if acamiss> 0
gen aca200=-9 if acamiss> 0
gen aca300=-9 if acamiss> 0
gen aca400=-9 if acamiss> 0
gen aca500=-9 if acamiss> 0
gen aca600=-9 if acamiss> 0
gen aca700=-9 if acamiss> 0
gen aca800=-9 if acamiss> 0

replace aca000=1 if acamiss<=0
replace aca100=0 if acamiss<=0
replace aca200=0 if acamiss<=0
replace aca300=0 if acamiss<=0
replace aca400=0 if acamiss<=0
replace aca500=0 if acamiss<=0
replace aca600=0 if acamiss<=0
replace aca700=0 if acamiss<=0
replace aca800=0 if acamiss<=0

foreach varname in aca000 aca100 aca200 aca300 aca400 aca500 aca600 aca700 aca800{
	replace `varname'=. if `varname'==-9
	}
	* AcaX00 dummy variables variables showing whether CM has one of a group of qualifications.
	label variable aca000 "1 if CM has no academic qualifications"
	label variable aca100 "1 if CM has bad O-levels "
	label variable aca200 "1 if CM has CSE 2-5, Other Scots "
	label variable aca300 "1 if CM has good O-levels "
	label variable aca400 "1 if CM has 1 A-level or more than 1 AS at grade A-C "
	label variable aca500 "1 if CM has 2 or more A-levels"
* page 285
	label variable aca600 "1 if CM has diploma "
	label variable aca700 "1 if CM has degree, PGCE, other degree level "
	label variable aca800 "1 if CM has higher degree"
	label define zero_one_ac_qual 0 "At least one academic qualification" 1 "No academic qualifications"
		label values aca000 zero_one_ac_qual 
* Bad O-levels: GCSEs D to E, GCEs D to E, Scottish SCE standard grades 4-5' .
* Good O-levels: CSE grade 1, GCSE grades A-C, GCE grades A-C, Scots standard grades 1-3, Scots lower or ordinary.
* 2 or more A-LEVELS: 2 or more A-levels, Scottish higher grade or Certificate of 6th Year Studies .
replace aca800=1 if (hdeg00==1)
replace aca000=0 if (hdeg00==1)

replace aca700=1 if (deg00==1 |odeg00==1 |pgce00==1)
replace aca000=0 if (deg00==1 |odeg00==1 |pgce00==1)

replace aca600=1 if (dip00==1)
replace aca000=0 if (dip00==1)

replace aca500=1 if (nalev00>1 | scot400==1 | scot500==1)
replace aca000=0 if (nalev00>1 | scot400==1 | scot500==1)

replace aca400=1 if (nalev00==1 | naslev00>1)
replace aca000=0 if (nalev00==1 | naslev00>1)

replace aca300=1 if (gcsehi00==1 | olevhi00==1 |csehi00==1 |scot200==1 |scot300==1)
replace aca000=0 if (gcsehi00==1 | olevhi00==1 |csehi00==1 |scot200==1 |scot300==1)

replace aca200=1 if (cselo00==1 | scot600==1)
replace aca000=0 if (cselo00==1 | scot600==1)

replace aca100=1 if (gcselo00==1 |olevlo00==1 |scotlo00==1)
replace aca000=0 if (gcselo00==1 |olevlo00==1 |scotlo00==1)

************* HAS CM OBTAINED A PARTICULAR VOCATIONAL QUALIFICATION? ************.
gen voc000=-9 if (vocmiss>0)
gen voc100=-9 if (vocmiss>0)
* page 286
gen voc200=-9 if (vocmiss>0)
gen voc300=-9 if (vocmiss>0)
gen voc400=-9 if (vocmiss>0)
gen voc500=-9 if (vocmiss>0)

replace voc000=1 if (vocmiss<=0)
replace voc100=0 if (vocmiss<=0)
replace voc200=0 if (vocmiss<=0)
replace voc300=0 if (vocmiss<=0)
replace voc400=0 if (vocmiss<=0)
replace voc500=0 if (vocmiss<=0)
	
foreach varname in voc000 voc100 voc200 voc300 voc400 voc500 {
	replace `varname'=. if `varname'==-9
	/**/													}

	
* VocX00 dummy variables variables showing whether CM has one of a group of qualifications.
	label variable voc000 "1 if CM has no vocational qualifications"
	label variable voc100 "1 if CM has vocational qualification equivalent to NVQ1"
	label variable voc200 "1 if CM has vocational qualification equivalent to NVQ2"
	label variable voc300 "1 if CM has vocational qualification equivalent to NVQ3"
	label variable voc400 "1 if CM has vocational qualification equivalent to NVQ4"
	label variable voc500 "1 if CM has vocational qualification equivalent to NVQ5"
	label define zero_one_voc_qual 0 "At least one vocational qualification" 1 "No vocational qualifications"
		label values voc000 zero_one_voc_qual
/* 100 'C&G Opo & Other, RSA 1, HGV, Other tech or bus qualification'
200 'C&G Craft-Inter-Ord-Part1-Cant say, RSA2, Insig,JIB NJC etc'
300 'C&G Advanced-Final-Part II or III, ONC-OND, RSA 3 '
400 'Nursing, BTEC HNC-HND, HNC-HND, C&G Full Tech (FTC)'
500 'NVQ awarded at level 5'.*/
replace voc500=1 if (nvq500==1 | nvq600==1)
replace voc000=0 if (nvq500==1 | nvq600==1)

	replace voc400=1 if (nurse00==1 |hnchnd00==1 |btec400==1 |rsa400==1 |nvq400==1)
	replace voc000=0 if (nurse00==1 |hnchnd00==1 |btec400==1 |rsa400==1 |nvq400==1)

replace voc300=1 if (city200==1 |city300==1 |city400==1 |oncond00==1 |btec300==1 |rsa300==1 |pit300==1 |nvq300==1 |gnvq300==1)
replace voc000=0 if (city200==1 |city300==1 |city400==1 |oncond00==1 |btec300==1 |rsa300==1 |pit300==1 |nvq300==1 |gnvq300==1)

	replace voc200=1 if (city100==1 |btec200==1 |rsa200==1 |pit200==1 |appren00==1 |nvq200==1 |gnvq200==1)
	replace voc000=0 if (city100==1 |btec200==1 |rsa200==1 |pit200==1 |appren00==1 |nvq200==1 |gnvq200==1)

	replace voc100=1 if (city500==1 |btec100==1 |rsa100==1 |pit100==1 |nvq100==1 |gnvq100==1 |hgv00==1 ///
	|othvoc00==1 |rsa500==1==1 |btec500==1 |pit400==1 |nvq700==1 |nvq800==1 |gnvq400==1)
	replace voc000=0 if (city500==1 |btec100==1 |rsa100==1 |pit100==1 |nvq100==1 |gnvq100==1 |hgv00==1 ///
	|othvoc00==1 |rsa500==1==1 |btec500==1 |pit400==1 |nvq700==1 |nvq800==1 |gnvq400==1)

		
	
	
* page 287
********************************************************************************************.
********************* HIGHEST QUALIFICATIONS ****************************.
********************************************************************************************.
/* This code gens the highest academic qualification, the highest vocational
qualification and the highest NVQ level recorded in the 2000 survey.
* Previous published work has used slightly different definitions of these variables
so you may need to adapt the code below.
* Check bad O-levels, many descriptions give them NVQ level of 0 .
* All vocational stuff needs checking especially pitmans btec rsa .*/
********************* HIGHEST ACADEMIC QUALIFICATION ***********************.
gen hiaca00=.
	* Note Kenzo made a mistake in translating this code, BB amended it 23/7/2013 - I've checked all of the SPSS ELSE statements in the documentation
	replace hiaca00=8 if (aca800==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=7 if (aca700==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=6 if (aca600==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=5 if (aca500==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=4 if (aca400==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=3 if (aca300==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=2 if (aca200==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=1 if (aca100==1 & acamiss==0 & missing(hiaca00) )
	replace hiaca00=0 if (            acamiss==0 & missing(hiaca00) ) /*BEN, PLEASE HELP CHECKING WHETHER THIS IS A CORRECT TRANSLATION OF THE ELSE IN PAGE 287*/

	label variable hiaca00 "Highest academic qualification recorded in 2000 survey"
#delimit ;
	label define hi_ac_qual_zero_seven 															
	0 "None"											
	1 "Bad O-levels"									
	2 "CSE 2-5, other Scottish school qualification"	
	3 "Good O levels"									
	4 "1 A level or more than 1 AS level at grade A-C"	
	5 "2 or more A-levels"								
	6 "Diploma"											
	7 "Degree, PGCE, other degree level"				
	8 "Higher degree" ;
#delimit cr	
* Notice diploma=degree .		
		label values hiaca00 hi_ac_qual_zero_seven
* page 288

recode hiaca00 (2=1)(3=2)(4=2)(5=3)(6=4)(7=4)(8=5), gen(nvqaca00) 
	label variable nvqaca00 "Highest NVQ level from an academic qualification in 2000 survey"
recode hiaca00 (2=1)(3=2)(4=2)(5=3)(6=4)(7=5)(8=6), gen(ghmaca00)
	label variable ghmaca00 "Highest academic qualification in 2000 survey ghm measure see also IFS"
	label define hi_ac_qual_2000 0 "None" 1 "Bad O levels, CSE 2-5" 2 "Good O-levels, 1 A-level" ///
	3 "2 or more A-levels" 4 "Sub-degree" 5 "Degree" 6 "Higher Degree"
		label values ghmaca00 hi_ac_qual_2000

********************* HIGHEST VOCATIONAL QUALIFICATION ***********************.
gen hivoc00=-9 if vocmiss>0
	replace hivoc00=5 if (voc500==1 & missing(hivoc00) )
	replace hivoc00=4 if (voc400==1 & missing(hivoc00) )
	replace hivoc00=3 if (voc300==1 & missing(hivoc00) ) 
	replace hivoc00=2 if (voc200==1 & missing(hivoc00) )
	replace hivoc00=1 if (voc100==1 & missing(hivoc00) )
	replace hivoc00=0 if (vocmiss==0 & missing(hivoc00)) 
		label variable hivoc00 "Highest vocational qualification recorded in 2000 survey"
	* HiVoc00 is also the highest NVQ level from a vocational qualification in 2000 survey.
		#delimit ;
	label define hivocl
		0 "None"
		1 "C&G Opo & Other, RSA 1, HGV, Other tech or bus qualification"
		2 "C&G Craft-Inter-Ord-Part1-Cant say, RSA2, Insig,JIB NJC etc"
		3 "C&G Advanced-Final-Part II or III, ONC-OND, RSA 3"
		4 "Nursing, BTEC HNC-HND, HNC-HND, C&G Full Tech (FTC)"
		5 "NVQ awarded at level 5";
		#delimit cr
		label values hivoc00 hivocl

*********************** Highest NVQ whatever type ********************************.
gen hinvq00=max(nvqaca00,hivoc00)
* page 289
	label variable hinvq00 "Highest NVQ level (whether academic or vocational)"
mvdecode hinvq00 hivoc00 hiaca00 nvqaca00, mv(-9=.d)

*********************** OTHER VARIABLES *******************************************.
/*gen group = 1 if (sample==1) 
* KENZO'S COMMENT:THE VARIABLE SAMPLE HAS NOT BEEN INTRODUCED BEFORE..
* HENCE, I WILL NOT RUN THIS SECTION!!
	replace group = 2 if (sample==2 & dmpart==1)
	replace group = 3 if (sample==2 & dmpart==2)
	label variable group "3 categories - BCS70 and NCDS by whether present in 1991 survey"
	lavel define groupl 1 "BCS70" 2 "NCDS present in 1991" 3 "NCDS not present in 1991"
		label value group groupl
recode sex (1=0) (2=1), gen(female)
	label define femalel 0 "male" 1 "female"
		label value female femalel*/

**********************************************************************************************.
******************************* SAVE DATA **********************************************.
**********************************************************************************************.
drop ALTodeg t1 t2 vocmiss1 acamiss1
drop gcsehi00-voc500
drop agelfted00-voctyp0100 edquals200-nummaths00 eqtp1404-eqtp1704 highal04 
// Added by BB 23/7/2013






////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////
// Comparisons of 2000 and 2004 education vars, and merging into a single version
// This is primarily based on the 2004 ed syntax - see separate (stage 1) .do file for 2004
////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////

/* NOTE: I cannot figure out how hq13_04 was derived - it seems to have information on people that otherwise 
doesn't appear in the surveys!  For this reason I've not used it here.  */

clonevar Dhinvq04 = nvq104		// This is generated in 1_highest_educ_2004.do
clonevar hinvq04 = hinvq00
	label var hinvq04 "Highest NVQ level (whether academic or vocational), merging 2000 and 2004 info"
	replace hinvq04 = Dhinvq04 if Dhinvq04>hinvq04 & ~missing(Dhinvq04)		// For new qualifications
	replace hinvq04 = Dhinvq04 if missing(hinvq04) & ~missing(Dhinvq04)		// For people missing in 2000
tab hinvq04 hinvq00, m
tab nvq104 if missing(hinvq00)

drop hiaca00-hivoc00 achq104-vnvq104 nvq104 Dhinvq04 hq13_04
save temp/bcs1986-12-incpc+alc+ed, replace

/* USED IMPLICITLY ABOVE, BUT WITH MY OWN CODE
* Highest academic qualification reported up to 2004 (nvq levels): combining nvqaca00 & bd7anvq1 variables.
gen bd7hanvq = (max(nvqaca00,bd7anvq1))
label var bd7hanvq "(derived) bcs 2004: highest nvq level from an academic qualification - info from 2000 & 2004 surveys"
label define bd7hanvq 0"none" 1"nvq1 level" 2"nvq2 level" 3"nvq3 level" 4"nvq4 level" 5"nvq5 level" -1"not applicable"

* Highest vocational qualification reported up to 2004 (nvq levels): combining hivoc00 & bd7vnvq1 variables.
gen bd7hvnvq = (max(hivoc00,bd7vnvq1)).
label var bd7hvnvq "(derived) bcs 2004: highest nvq level from a vocational qualification - info from 2000 & 2004 surveys"
label define bd7hvnvq 0"none" 1"nvq1 level" 2"nvq2 level" 3"nvq3 level" 4"nvq4 level" 5"nvq5 level" -1"not applicable"
*/

	/* NOT USED because they're not used in the 2000 syntax otherwise above
		* Highest academic qualification up to 2004: comparing with hiaca00 variable in 2000 survey.
		compute bd7hachq = (max(hiaca00,bd7achq1)).
		variable labels bd7hachq "(derived) bcs 2004: highest academic qualification - info from 2000 & 2004 surveys".
		value labels bd7hachq 0 "no academic qualification" 1 "gcse d-e" 2 "cses2-5, other scottish quals" 3 "gcse a-c, good o levels scot st&ards" ///
			4 "as levels | 1 a level" 5 "2+ a levels, scot higher/6th" 6"diploma" 7"degree, pgce, other degree level qual" ///
			8"higher degree" -1"not applicable" -9 "refusal" -8 "don""t know".
		* Highest nvq level from an academic | vocational qualification reported in 2004: combining hinvq00 & bd7nvq1 variables.
		compute bd7hnvq = (max(hinvq00,bd7nvq1)).
		variable labels bd7hnvq "(derived) bcs 2004: highest nvq level from an academic | vocational qualification - info from 2000 & 2004 surveys".
		value labels bd7hnvq 0"none" 1"nvq1 level" 2"nvq2 level" 3"nvq3 level" 4"nvq4 level" 5"nvq5 level" -1"not applicable".
	*/


