* v4 is the original Addiction submission, v5 adds analyses to respond to reviewer comments

//////////////////////////////////////////////////
//////////////////////////////////////////////////
// OUTCOMES
//////////////////////////////////////////////////
//////////////////////////////////////////////////

/* Plan of models: 	1: Cross-sectional | 2: Panel |  3: IV (split by different instruments)*/
estimates drop _all


***************************************************
***************************************************
** Linear & FE models
***************************************************
***************************************************
/* A note on quadratics:
	The level of consumption at which satisfaction is equal to not drinking
		Ax2 +B x = 0     => x(Ax + B)=)     =>    x=-B/A
	The level of consumption of maximum wellbeing
		D(Ax2 + Bx)/dx=0 => 2Ax + B = 0     => x= -B/2A		*/
* The main variable lists - linear & quadratic
local reg1	"i.nevdrk c.alctotunOLD"
local reg2	"i.nevdrk c.alctotunOLD 				${stablevars} ${varyvars}"
local reg11 "i.nevdrk c.alctotunOLD##c.alctotunOLD"
local reg12	"i.nevdrk c.alctotunOLD##c.alctotunOLD	${stablevars} ${varyvars}"
local reg15 "i.nevdrk c.alctotunNEW##c.alctotunNEW"
local reg16	"i.nevdrk c.alctotunNEW##c.alctotunNEW	${stablevars} ${varyvars}"
* Other versions of alcohol consumption
local reg21 "i.nevdrk i.alcgrpOLD"
local reg22 "i.nevdrk i.alcgrpOLD					${stablevars} ${varyvars}"
local reg23 "i.nevdrk i.alcgrpNEW					${stablevars} ${varyvars}"
local reg32 "i.nevdrk i.cageyr						${stablevars} ${varyvars}"
local reg36 "ib(5).alcfreq							${stablevars} ${varyvars}"
* Collections of control variables for preferred outcome cat
local reg61	"i.nevdrk c.alctotunOLD##c.alctotunOLD 	${stablevars} ${varyvars} ${morevars} "
local reg62	"i.nevdrk c.alctotunOLD##c.alctotunOLD 	${stablevars} ${varyvars} 							 " // Follow-up sample
local if62 	"& e(sample)"
local reg63	"i.nevdrk c.alctotunOLD##c.alctotunOLD 	${stablevars} ${varyvars} 				${ctrls00_04}"
local reg64	"i.nevdrk c.alctotunOLD##c.alctotunOLD 	${stablevars} ${varyvars} 							 " // Follow-up sample
local if64	"& e(sample)"
* Subgroups 
forvalues loop = 41/45	{
	local reg`loop' "i.nevdrk i.alcgrpOLD					${stablevars} ${varyvars}"
/**/					}
local if41	"& (wavenum==1 | wavenum==2)"
local if42	"& (wavenum==2 | wavenum==3)"
local if44	"& male==1"
local if45	"& male==0"
forvalues loop = 46/49	{
	local reg`loop' "i.nevdrk c.alctotunOLD##c.alctotunOLD	${stablevars} ${varyvars}"
/**/					}
local if46	"& (wavenum==1 | wavenum==2)"
local if47	"& (wavenum==2 | wavenum==3)"
local if48	"& male==1"
local if49	"& male==0"
* Interactions - FE models only
local reg51	"i.alcgrpOLD##i.male							${stablevars} ${varyvars}"
local reg52	"i.alcgrpNEW##i.male							${stablevars} ${varyvars}"
local reg53	"(c.alctotunNEW##c.alctotunNEW)##i.male 		${stablevars} ${varyvars}"
local reg55	"i.alcgrpOLD##ib(2).wavenum						${stablevars} ${varyvars}"
local reg56	"i.alcgrpNEW##ib(2).wavenum						${stablevars} ${varyvars}"
local reg57	"(c.alctotunNEW##c.alctotunNEW)##ib(2).wavenum	${stablevars} ${varyvars}"
	*************************************************
	*************************************************
	* Additional analyses in response to reviewers
	*************************************************
	*************************************************
	// Interactions by sex
	local reg3	"i.nevdrk i.alcgrpOLD male#(i.nevdrk i.alcgrpOLD)"			// Same as reg21 but with additional interaction with sex
	local reg4	"i.nevdrk i.alcgrpOLD male#(i.nevdrk i.alcgrpOLD) ${stablevars} ${varyvars}" // Same as reg22 but with additional interaction with sex
	// Excluding never drinkers
	local reg5 	"i.alcgrpOLD"													// The same as reg21, but with i.nevdrk removed
	local reg6 	"i.alcgrpOLD					${stablevars} ${varyvars}"		// The same as reg22, but with i.nevdrk removed
	local if5	"& nevdrk==0"
	local if6	"& nevdrk==0"
	// Excluding people whose drinking doesn't change across waves
	local reg7 	"`reg21'"														// The same as reg21, but with different IF below
	local reg8 	"`reg22'"														// The same as reg22, but with different IF below
	local if7	"& anychange==1"
	local if8	"& anychange==1"
	// Controlling for the lagged dependent variable, OLS models only (NOT FE)
	local reg101 "`reg21' Llifesat"
	local reg102 "`reg22' Llifesat"
	local reg103 "`reg32' Llifesat"
	local reg104 "`reg36' Llifesat"
* The models
foreach set in lin fe linextra	{
*foreach set in lin  {
*	if "`set'"=="lin"		local loop "51/53"			// Was 1/45, changed 26th Aug 2015 in response to reviewer query
	if "`set'"=="lin"		local loop "1/57"			// Was 1/45, changed 26th Aug 2015 in response to reviewer query
	if "`set'"=="fe"		local loop "1/69"
	if "`set'"=="linextra" 	local loop "101/105"		// I wanted to run some analyses ONLY with standard OLS, not FE - so I ended up introducing this, clumsily
	forvalues i = `loop'	{
		if "reg`i'"~=""		{
			dis _newline(5) in red "Reg `i': `set' models"
			if "`set'"=="lin" 		eststo lin`i': reg   lifesat `reg`i'' if alctotunNEW<${maxalc} `if`i'', vce(cluster bcsnumid)
			if "`set'"=="fe"  		eststo fe`i':  xtreg lifesat `reg`i'' if alctotunNEW<${maxalc} `if`i'', fe
			if "`set'"=="linextra" 	eststo lin`i': reg   lifesat `reg`i'' if alctotunNEW<${maxalc} `if`i'', vce(cluster bcsnumid)
			*******************************
			* Postestimation
			*******************************
			* Number of people in the model ('bothwaves' is old, from when I was just looking at 2000 and 2004)
			estadd scalar numbothwaves = e(df_r) + 1			// I figured this out from a fragment of code stored in OneNote - it refers to the number of fixed effect dummies used
			matrix firstworking = e(b)'	
			local cmdline = e(cmdline)
			* Joint test of all of the alcohol categorical variables
			if strmatch("`cmdline'", "*alcgrp*")==1 	{
				dis _newline(5) in red "alcgrp: Joint test of independent variables"
				testparm i.alcgrp???
				estadd scalar jointtest = r(p)	
			/**/										}	
			if strmatch("`cmdline'", "*alcfreq*")==1 	{
				dis _newline(5) in red "alcfreq: Joint test of independent variables"
				testparm i.alcfreq
				estadd scalar jointtest = r(p)	
			/**/										}	
			// Postestimation for quadratic equations only
			if strmatch("`cmdline'", "*c.alctotun*##c.alctotun*")==1 	{
				if ((firstworking[3,1]>0 & firstworking[4,1]<0) | (firstworking[3,1]<0 & firstworking[4,1]>0))	{
					dis _newline(5) in red "acltotun: Turning point"
						estadd scalar turningpoint = -firstworking[3,1]/(2*firstworking[4,1])
					dis _newline(2) in red "acltotun: Consumption with happiness equal to abstaining"
						estadd scalar abstequiv = -firstworking[3,1]/(firstworking[4,1])
					/**/																						}
				dis _newline(2) in red "acltotun: Joint test of independent variables"
					testparm alctotun??? c.alctotun???#c.alctotun???
					estadd scalar jointtest = r(p)		
			/**/															}	
		/**/					}	
	/**/					}					
/**/					}					
// End FE models

	
// Getting the appropriate n
	/* 	This seemingly complex code is a way of seeing how many waves per person contributed to each mode.
		You can see in the final output that this gives the number of people who contribute only 1 wave, who contribute 2
		waves, and who contribute in 3 waves.  I tried and failed to find a way of getting this information any other way!
		Currently it only does this for a subset of models, but it's straightforward to do for all of them.
	END OF NOTE */
foreach set in lin fe 	{
	forvalues i = 1/105		{
		dis "Set is `set', is is `i'"
		capture estimates restore `set'`i'
		if _rc==0	{
			// Generating the 
			capture drop incount insample inW?
			tsset bcsnumid wavenum
			gen insample = e(sample)
			foreach wave in 2 3 	{
				local forward = `wave'-1
				gen inW`wave' = F`forward'.insample if wavenum==1
			}	
			sum insample inW2 inW3 if wavenum==1
			egen incount = rowtotal(insample inW2 inW3) if wavenum==1
			// Outputs
			prop incount if wavenum==1
			local numpeople = e(N)
			matrix working = e(b)'
			local numwaves = rowsof(working)
			estadd scalar n_1obs 	= working[2,1]*`numpeople', replace							: `set'`i'
			estadd scalar n_2obs 	= working[3,1]*`numpeople', replace							: `set'`i'
			if `numwaves'==4	{
				estadd scalar n_3obs 	= working[4,1]*`numpeople', replace						: `set'`i'	
				estadd scalar n_within 	= (working[4,1]+working[3,1])*`numpeople', replace		: `set'`i'	
			}
			else estadd scalar n_within = working[3,1]*`numpeople', replace						: `set'`i'
		}
	}
}

	
// Saving the estimates for future use (e.g. checking, postestimation)	
estwrite * using "${dir}\estimates_OLSandFE_${filename}", id(uniqueid) replace


	
//////////////////////////////////////////////////
// Outputting the results + Postestimation
//////////////////////////////////////////////////
/* This is a code fragment that I can use to reload the results if necessary
estimates drop _all
estread using "${dir}\estimates_OLSandFE_${filename}", id(uniqueid)
*/

// OUTPUTTING TO EXCEL
esttab fe* lin* using `"${dodir}\0.output_FEandOLS.csv"', csv replace not r2 scalars("n_within People w/ 2+ obs" "n_1obs People in 1 wave" "n_2obs People in 2 waves" "n_3obs People in 3 waves" "df_b control df" _ jointtest __ turningpoint abstequiv) ///
	sfmt(%5.0f %5.0f %5.0f %2.0f %2.0f %3.2f %3.2f %2.1f) order(*inc *alc* *drk* *cage*) star(+ 0.10 * 0.05 ** 0.01) varwidth(25) nodepvars nonumbers


// POSTESTIMATION
* Subgroups & interactions - FE only - 41 42 43 44 45
esttab fe41 fe42 fe46 fe47 fe55 fe56 fe57, not r2 scalars("numbothwaves n people" "df_b control df" _ jointtest __ turningpoint abstequiv) sfmt(%5.0f %2.0f %2.0f %3.2f %3.2f %2.1f) b(%5.4f) ///
	keep(*alc* *drk*) star(+ 0.10 * 0.05 ** 0.01) varwidth(25) nodepvars nonumbers ///
	mtitles ("ages 30-34" "ages 34-42" "ages 30-34" "ages 34-42" )
esttab fe44 fe45 fe48 fe49 fe51 fe52 fe53, not r2 scalars("numbothwaves n people" "df_b control df" _ jointtest __ turningpoint abstequiv) sfmt(%5.0f %2.0f %2.0f %3.2f %3.2f %2.1f) b(%7.6f) ///
	keep(*alc* *drk* *male*) drop(*0b* *o.male *#co.alctotun*) star(+ 0.10 * 0.05 ** 0.01) varwidth(25) nodepvars nonumbers ///
	mtitles ("male" "female" "male" "female")
estimates restore fe51
	testparm alc*#1.male 
estimates restore fe52
	testparm alc*#1.male 
estimates restore fe53
	testparm 1.male#c.alctotunNEW 1.male#c.alctotunNEW#c.alctotunNEW
estimates restore lin51
	testparm alc*#1.male 
estimates restore lin52
	testparm alc*#1.male 
estimates restore lin53
	testparm 1.male#c.alctotunNEW 1.male#c.alctotunNEW#c.alctotunNEW

/* Marginal effects for continuous variables - old version only	
estimates restore lin12
	matrix working = e(b)'
	local i = 100
	scalar working = (`i'*working[2,1] + `i'^2*working[3,1])
	dis "Estimated effect at `i' units is " working
estimates restore fe12
	margins, at(alctotunOLD=(-50(5)50))
	marginsplot, recast(line) plotopts(lcolor(black) lwidth(medthick)) recastci(rarea) ciopts(color(gs13)) xlabel(-50(10)50) ///
		title("Change in life satisfaction as drinking changes" " ") xtitle(" " "Change in alcohol consumption age 30 to 34") 		 ///
		ytitle("Estimated life satisfaction" " ") scale(1) ysize(8) xsize(10) graphregion(fcolor(white))
END OF OLD ANALYSIS FRAGMENT */
